# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: common/extraction_objects.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1f\x63ommon/extraction_objects.proto\x12\x12\x65xtraction_objects\"\x82\x01\n\x08\x42ookmark\x12\x42\n\x0b\x63heckpoints\x18\x01 \x03(\x0b\x32-.extraction_objects.Bookmark.CheckpointsEntry\x1a\x32\n\x10\x43heckpointsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xbe\x01\n\x1d\x45xtractionProgressDetailGroup\x12\x0f\n\x07message\x18\x01 \x01(\t\x12\x0b\n\x03key\x18\x02 \x01(\t\x12O\n\x07\x64\x65tails\x18\x03 \x03(\x0b\x32>.extraction_objects.ExtractionProgressDetailGroup.DetailsEntry\x1a.\n\x0c\x44\x65tailsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"8\n\x18\x45xtractionProgressDetail\x12\x0f\n\x07message\x18\x01 \x01(\t\x12\x0b\n\x03key\x18\x02 \x01(\t\"\xd8\x01\n\x12\x45xtractionProgress\x12\x11\n\x07message\x18\x01 \x01(\tH\x00\x12J\n\x12\x65xtraction_message\x18\x02 \x01(\x0b\x32,.extraction_objects.ExtractionProgressDetailH\x00\x12M\n\x10progress_details\x18\x03 \x01(\x0b\x32\x31.extraction_objects.ExtractionProgressDetailGroupH\x00\x42\x14\n\x12\x45xtractionProgress\"\x87\x01\n\rKeyedBookmark\x12\x0b\n\x03key\x18\x01 \x01(\t\x12;\n\x05value\x18\x02 \x03(\x0b\x32,.extraction_objects.KeyedBookmark.ValueEntry\x1a,\n\nValueEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42L\n\"alation.sdk.grpc.common.extractionB\x11\x45xtractionObjectsP\x01Z\x11\x63ommon/extractionb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'common.extraction_objects_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\"alation.sdk.grpc.common.extractionB\021ExtractionObjectsP\001Z\021common/extraction'
  _globals['_BOOKMARK_CHECKPOINTSENTRY']._options = None
  _globals['_BOOKMARK_CHECKPOINTSENTRY']._serialized_options = b'8\001'
  _globals['_EXTRACTIONPROGRESSDETAILGROUP_DETAILSENTRY']._options = None
  _globals['_EXTRACTIONPROGRESSDETAILGROUP_DETAILSENTRY']._serialized_options = b'8\001'
  _globals['_KEYEDBOOKMARK_VALUEENTRY']._options = None
  _globals['_KEYEDBOOKMARK_VALUEENTRY']._serialized_options = b'8\001'
  _globals['_BOOKMARK']._serialized_start=56
  _globals['_BOOKMARK']._serialized_end=186
  _globals['_BOOKMARK_CHECKPOINTSENTRY']._serialized_start=136
  _globals['_BOOKMARK_CHECKPOINTSENTRY']._serialized_end=186
  _globals['_EXTRACTIONPROGRESSDETAILGROUP']._serialized_start=189
  _globals['_EXTRACTIONPROGRESSDETAILGROUP']._serialized_end=379
  _globals['_EXTRACTIONPROGRESSDETAILGROUP_DETAILSENTRY']._serialized_start=333
  _globals['_EXTRACTIONPROGRESSDETAILGROUP_DETAILSENTRY']._serialized_end=379
  _globals['_EXTRACTIONPROGRESSDETAIL']._serialized_start=381
  _globals['_EXTRACTIONPROGRESSDETAIL']._serialized_end=437
  _globals['_EXTRACTIONPROGRESS']._serialized_start=440
  _globals['_EXTRACTIONPROGRESS']._serialized_end=656
  _globals['_KEYEDBOOKMARK']._serialized_start=659
  _globals['_KEYEDBOOKMARK']._serialized_end=794
  _globals['_KEYEDBOOKMARK_VALUEENTRY']._serialized_start=750
  _globals['_KEYEDBOOKMARK_VALUEENTRY']._serialized_end=794
# @@protoc_insertion_point(module_scope)
