# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fs/mde.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from queryservice_client.protobuf.common import configuration_pb2 as common_dot_configuration__pb2
from fs import mde_objects_pb2 as fs_dot_mde__objects__pb2
from queryservice_client.protobuf.common import job_error_pb2 as common_dot_job__error__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0c\x66s/mde.proto\x12\x06\x66s.mde\x1a\x1a\x63ommon/configuration.proto\x1a\x14\x66s/mde_objects.proto\x1a\x16\x63ommon/job_error.proto\"O\n\x17\x46ilterExtractionRequest\x12\x34\n\rconfiguration\x18\x01 \x01(\x0b\x32\x1d.common.ProtobufConfiguration\">\n\x18\x46ilterExtractionResponse\x12\"\n\x04path\x18\x01 \x01(\x0b\x32\x14.fs.mde_objects.Path\"\xc0\x01\n\x19MetadataExtractionRequest\x12\x34\n\rconfiguration\x18\x01 \x01(\x0b\x32\x1d.common.ProtobufConfiguration\x12*\n\x08\x62ookmark\x18\x02 \x03(\x0b\x32\x18.fs.mde_objects.Bookmark\x12&\n\x06\x66ilter\x18\x03 \x01(\x0b\x32\x16.fs.mde_objects.Filter\x12\x19\n\x11is_include_filter\x18\x04 \x01(\x08\"\xf0\x01\n\x1aMetadataExtractionResponse\x12$\n\x04\x66ile\x18\x01 \x01(\x0b\x32\x14.fs.mde_objects.FileH\x00\x12,\n\x08\x62ookmark\x18\x02 \x01(\x0b\x32\x18.fs.mde_objects.BookmarkH\x00\x12@\n\x12\x65xtractionProgress\x18\x03 \x01(\x0b\x32\".fs.mde_objects.ExtractionProgressH\x00\x12!\n\x05\x65rror\x18\x04 \x01(\x0b\x32\x10.job_error.ErrorH\x00\x42\x19\n\x17\x45xtractMetadataResponse\"\xf3\x01\n\x18\x43olumnExtractionResponse\x12(\n\x06\x63olumn\x18\x01 \x01(\x0b\x32\x16.fs.mde_objects.ColumnH\x00\x12,\n\x08\x62ookmark\x18\x02 \x01(\x0b\x32\x18.fs.mde_objects.BookmarkH\x00\x12@\n\x12\x65xtractionProgress\x18\x03 \x01(\x0b\x32\".fs.mde_objects.ExtractionProgressH\x00\x12!\n\x05\x65rror\x18\x04 \x01(\x0b\x32\x10.job_error.ErrorH\x00\x42\x1a\n\x18\x43olumnExtractionResponseB7\n\x17\x61lation.sdk.fs.grpc.mdeB\x12MetadataExtractionP\x01Z\x06\x66s/mdeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'fs.mde_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\027alation.sdk.fs.grpc.mdeB\022MetadataExtractionP\001Z\006fs/mde'
  _globals['_FILTEREXTRACTIONREQUEST']._serialized_start=98
  _globals['_FILTEREXTRACTIONREQUEST']._serialized_end=177
  _globals['_FILTEREXTRACTIONRESPONSE']._serialized_start=179
  _globals['_FILTEREXTRACTIONRESPONSE']._serialized_end=241
  _globals['_METADATAEXTRACTIONREQUEST']._serialized_start=244
  _globals['_METADATAEXTRACTIONREQUEST']._serialized_end=436
  _globals['_METADATAEXTRACTIONRESPONSE']._serialized_start=439
  _globals['_METADATAEXTRACTIONRESPONSE']._serialized_end=679
  _globals['_COLUMNEXTRACTIONRESPONSE']._serialized_start=682
  _globals['_COLUMNEXTRACTIONRESPONSE']._serialized_end=925
# @@protoc_insertion_point(module_scope)
