# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: common/datasource.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17\x63ommon/datasource.proto\x12\ndatasource\"9\n\x0e\x43onnectionInfo\x12\x0b\n\x03uri\x18\x01 \x01(\t\x12\x0c\n\x04host\x18\x02 \x01(\t\x12\x0c\n\x04port\x18\x03 \x01(\x05\"\x06\n\x04Self\"\xa6\x01\n\nDataSource\x12$\n\x04type\x18\x01 \x01(\x0e\x32\x16.datasource.SourceType\x12 \n\x04self\x18\x14 \x01(\x0b\x32\x10.datasource.SelfH\x00\x12\x0c\n\x02id\x18\x15 \x01(\x05H\x00\x12\x30\n\nconnection\x18\x16 \x01(\x0b\x32\x1a.datasource.ConnectionInfoH\x00\x42\x10\n\x0eresolutionInfo*1\n\nSourceType\x12\x08\n\x04None\x10\x00\x12\t\n\x05RDBMS\x10\x01\x12\x06\n\x02\x42I\x10\x02\x12\x06\n\x02\x46S\x10\x03\x42\x46\n\"alation.sdk.grpc.common.datasourceB\x0b\x44\x61taSourcesP\x01Z\x11\x63ommon/datasourceb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'common.datasource_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\"alation.sdk.grpc.common.datasourceB\013DataSourcesP\001Z\021common/datasource'
  _globals['_SOURCETYPE']._serialized_start=275
  _globals['_SOURCETYPE']._serialized_end=324
  _globals['_CONNECTIONINFO']._serialized_start=39
  _globals['_CONNECTIONINFO']._serialized_end=96
  _globals['_SELF']._serialized_start=98
  _globals['_SELF']._serialized_end=104
  _globals['_DATASOURCE']._serialized_start=107
  _globals['_DATASOURCE']._serialized_end=273
# @@protoc_insertion_point(module_scope)
