# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fs/mde_objects.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14\x66s/mde_objects.proto\x12\x0e\x66s.mde_objects\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1cgoogle/protobuf/struct.proto\"\x18\n\x04Path\x12\x10\n\x08\x66ilePath\x18\x01 \x01(\t\"n\n\x12\x45xtractionProgress\x12\x11\n\x07message\x18\x01 \x01(\tH\x00\x12/\n\x0e\x63ompletedOtype\x18\x02 \x01(\x0e\x32\x15.fs.mde_objects.OtypeH\x00\x42\x14\n\x12\x45xtractionProgress\",\n\x06\x46ilter\x12\"\n\x04path\x18\x01 \x03(\x0b\x32\x14.fs.mde_objects.Path\"\xe0\x02\n\x04\x46ile\x12\x10\n\x08rootPath\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x03(\t\x12\x0c\n\x04type\x18\x03 \x01(\t\x12\x15\n\rpathDelimiter\x18\x04 \x01(\t\x12\x13\n\x0bisDirectory\x18\x05 \x01(\x08\x12\x11\n\tisDeleted\x18\x06 \x01(\x08\x12\r\n\x05owner\x18\x07 \x01(\t\x12\x13\n\x0bsizeInBytes\x18\x08 \x01(\x04\x12.\n\ncreateTime\x18\t \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x39\n\x15lastModifiedTimestamp\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x39\n\x15lastAccessedTimestamp\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\r\n\x05group\x18\x0c \x01(\t\x12\x12\n\npermission\x18\r \x01(\t\"?\n\x08\x42ookmark\x12\x0b\n\x03key\x18\x01 \x01(\t\x12&\n\x05value\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\";\n\x08\x43olumnId\x12\x0c\n\x04path\x18\x01 \x03(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0bisDirectory\x18\x03 \x01(\x08\"\xd4\x01\n\nColumnType\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07remarks\x18\x02 \x01(\t\x12=\n\nnormalized\x18\x03 \x01(\x0e\x32).fs.mde_objects.ColumnType.NormalizedType\"h\n\x0eNormalizedType\x12\t\n\x05OTHER\x10\x00\x12\x08\n\x04\x42OOL\x10\x01\x12\x08\n\x04\x44\x41TE\x10\x02\x12\x07\n\x03INT\x10\x03\x12\t\n\x05\x46LOAT\x10\x04\x12\n\n\x06STRING\x10\x05\x12\x08\n\x04TIME\x10\x06\x12\r\n\tTIMESTAMP\x10\x07\"~\n\x06\x43olumn\x12$\n\x02id\x18\x01 \x01(\x0b\x32\x18.fs.mde_objects.ColumnId\x12(\n\x04type\x18\x02 \x01(\x0b\x32\x1a.fs.mde_objects.ColumnType\x12\x10\n\x08position\x18\x03 \x01(\x05\x12\x12\n\nisNullable\x18\x04 \x01(\x08*+\n\x05Otype\x12\x08\n\x04\x46ILE\x10\x00\x12\x0c\n\x08\x42OOKMARK\x10\x01\x12\n\n\x06\x43OLUMN\x10\x02\x42<\n\x17\x61lation.sdk.fs.grpc.mdeB\x0fMetadataObjectsP\x01Z\x0e\x66s/mde_objectsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'fs.mde_objects_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\027alation.sdk.fs.grpc.mdeB\017MetadataObjectsP\001Z\016fs/mde_objects'
  _globals['_OTYPE']._serialized_start=1111
  _globals['_OTYPE']._serialized_end=1154
  _globals['_PATH']._serialized_start=103
  _globals['_PATH']._serialized_end=127
  _globals['_EXTRACTIONPROGRESS']._serialized_start=129
  _globals['_EXTRACTIONPROGRESS']._serialized_end=239
  _globals['_FILTER']._serialized_start=241
  _globals['_FILTER']._serialized_end=285
  _globals['_FILE']._serialized_start=288
  _globals['_FILE']._serialized_end=640
  _globals['_BOOKMARK']._serialized_start=642
  _globals['_BOOKMARK']._serialized_end=705
  _globals['_COLUMNID']._serialized_start=707
  _globals['_COLUMNID']._serialized_end=766
  _globals['_COLUMNTYPE']._serialized_start=769
  _globals['_COLUMNTYPE']._serialized_end=981
  _globals['_COLUMNTYPE_NORMALIZEDTYPE']._serialized_start=877
  _globals['_COLUMNTYPE_NORMALIZEDTYPE']._serialized_end=981
  _globals['_COLUMN']._serialized_start=983
  _globals['_COLUMN']._serialized_end=1109
# @@protoc_insertion_point(module_scope)
