# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cf/cf_objects.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from queryservice_client.protobuf.rdbms import mde_objects_pb2 as rdbms_dot_mde__objects__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13\x63\x66/cf_objects.proto\x12\x11ocf.cf.cf_objects\x1a\x17rdbms/mde_objects.proto\"\x1e\n\rCustomFieldId\x12\r\n\x05parts\x18\x01 \x03(\t\"y\n\x10\x43ustomFieldApiId\x12\x39\n\x03key\x18\x01 \x03(\x0b\x32,.ocf.cf.cf_objects.CustomFieldApiId.KeyEntry\x1a*\n\x08KeyEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xf3\x01\n\x0b\x43ustomField\x12,\n\x02id\x18\x01 \x01(\x0b\x32 .ocf.cf.cf_objects.CustomFieldId\x12\x32\n\x05\x61piId\x18\x02 \x01(\x0b\x32#.ocf.cf.cf_objects.CustomFieldApiId\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x1a\n\x12\x66ullyQualifiedName\x18\x04 \x01(\t\x12;\n\x0f\x63ustomFieldType\x18\x05 \x01(\x0e\x32\".ocf.cf.cf_objects.CustomFieldType\x12\x1b\n\x13\x61llowedPickerValues\x18\x06 \x03(\t\"`\n\x16\x43ustomFieldPickerValue\x12\x37\n\rcustomFieldId\x18\x01 \x01(\x0b\x32 .ocf.cf.cf_objects.CustomFieldId\x12\r\n\x05value\x18\x02 \x01(\t\"\xf4\x01\n\x0f\x43ustomFieldLink\x12/\n\x08schemaId\x18\x01 \x01(\x0b\x32\x1b.rdbms.mde_objects.SchemaIdH\x00\x12-\n\x07tableId\x18\x02 \x01(\x0b\x32\x1a.rdbms.mde_objects.TableIdH\x00\x12/\n\x08\x63olumnId\x18\x03 \x01(\x0b\x32\x1b.rdbms.mde_objects.ColumnIdH\x00\x12@\n\x0bpickerValue\x18\x04 \x01(\x0b\x32).ocf.cf.cf_objects.CustomFieldPickerValueH\x01\x42\x05\n\x03oidB\x07\n\x05value\"2\n\x14\x43ustomFieldSyncValue\x12\x11\n\x07vString\x18\x01 \x01(\tH\x00\x42\x07\n\x05value\"\x81\x03\n\x16\x43ustomFieldValueUpdate\x12\x35\n\x0bschemaApiId\x18\x01 \x01(\x0b\x32\x1e.rdbms.mde_objects.SchemaApiIdH\x00\x12\x33\n\ntableApiId\x18\x02 \x01(\x0b\x32\x1d.rdbms.mde_objects.TableApiIdH\x00\x12\x35\n\x0b\x63olumnApiId\x18\x03 \x01(\x0b\x32\x1e.rdbms.mde_objects.ColumnApiIdH\x00\x12=\n\x10\x63ustomFieldApiId\x18\x04 \x01(\x0b\x32#.ocf.cf.cf_objects.CustomFieldApiId\x12;\n\x0f\x63ustomFieldType\x18\x05 \x01(\x0e\x32\".ocf.cf.cf_objects.CustomFieldType\x12\x39\n\x08newValue\x18\x06 \x01(\x0b\x32\'.ocf.cf.cf_objects.CustomFieldSyncValueB\r\n\x0bobjectApiId*\x1d\n\x0f\x43ustomFieldType\x12\n\n\x06PICKER\x10\x00\x42\x32\n\x1b\x61lation.sdk.ocf.cf.grpc.mdeB\x11\x43\x46MetadataObjectsP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cf.cf_objects_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033alation.sdk.ocf.cf.grpc.mdeB\021CFMetadataObjectsP\001'
  _globals['_CUSTOMFIELDAPIID_KEYENTRY']._options = None
  _globals['_CUSTOMFIELDAPIID_KEYENTRY']._serialized_options = b'8\001'
  _globals['_CUSTOMFIELDTYPE']._serialized_start=1253
  _globals['_CUSTOMFIELDTYPE']._serialized_end=1282
  _globals['_CUSTOMFIELDID']._serialized_start=67
  _globals['_CUSTOMFIELDID']._serialized_end=97
  _globals['_CUSTOMFIELDAPIID']._serialized_start=99
  _globals['_CUSTOMFIELDAPIID']._serialized_end=220
  _globals['_CUSTOMFIELDAPIID_KEYENTRY']._serialized_start=178
  _globals['_CUSTOMFIELDAPIID_KEYENTRY']._serialized_end=220
  _globals['_CUSTOMFIELD']._serialized_start=223
  _globals['_CUSTOMFIELD']._serialized_end=466
  _globals['_CUSTOMFIELDPICKERVALUE']._serialized_start=468
  _globals['_CUSTOMFIELDPICKERVALUE']._serialized_end=564
  _globals['_CUSTOMFIELDLINK']._serialized_start=567
  _globals['_CUSTOMFIELDLINK']._serialized_end=811
  _globals['_CUSTOMFIELDSYNCVALUE']._serialized_start=813
  _globals['_CUSTOMFIELDSYNCVALUE']._serialized_end=863
  _globals['_CUSTOMFIELDVALUEUPDATE']._serialized_start=866
  _globals['_CUSTOMFIELDVALUEUPDATE']._serialized_end=1251
# @@protoc_insertion_point(module_scope)
