# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fs/fs_profiling.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from queryservice_client.protobuf.common import configuration_pb2 as common_dot_configuration__pb2
from queryservice_client.protobuf.common import auth_pb2 as common_dot_auth__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15\x66s/fs_profiling.proto\x12\x0c\x66s.profiling\x1a\x1a\x63ommon/configuration.proto\x1a\x11\x63ommon/auth.proto\"\x9d\x01\n\x14\x46ileProfilingRequest\x12\x34\n\rconfiguration\x18\x01 \x01(\x0b\x32\x1d.common.ProtobufConfiguration\x12\x35\n\x0fprofileRequests\x18\x02 \x03(\x0b\x32\x1c.fs.profiling.ProfileRequest\x12\x18\n\x04\x61uth\x18\x03 \x01(\x0b\x32\n.auth.Auth\"\xd3\x01\n\x0eProfileRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x03(\t\x12%\n\x07\x63olumns\x18\x03 \x03(\x0b\x32\x14.fs.profiling.Column\x12\x0f\n\x07timeout\x18\x04 \x01(\r\x12\x16\n\x0epopulationSize\x18\x05 \x01(\r\x12\x12\n\nsampleSize\x18\x06 \x01(\r\x12.\n\x10sensitiveColumns\x18\x07 \x03(\x0b\x32\x14.fs.profiling.Column\x12\x13\n\x0bisDirectory\x18\x08 \x01(\x08\"\"\n\x06\x43olumn\x12\n\n\x02id\x18\x01 \x01(\x04\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x8e\x01\n\x15\x46ileProfilingResponse\x12\n\n\x02id\x18\x01 \x01(\t\x12%\n\nrowSamples\x18\x02 \x03(\x0b\x32\x11.fs.profiling.Row\x12\x1b\n\x13numberOfRowsSampled\x18\x03 \x01(\r\x12\x14\n\x0csecondsTaken\x18\x04 \x01(\r\x12\x0f\n\x07hasMore\x18\x05 \x01(\x08\"\x15\n\x03Row\x12\x0e\n\x06values\x18\x01 \x03(\tB:\n\x1d\x61lation.sdk.fs.grpc.profilingB\tProfilingP\x01Z\x0c\x66s/profilingb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'fs.fs_profiling_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\035alation.sdk.fs.grpc.profilingB\tProfilingP\001Z\014fs/profiling'
  _globals['_FILEPROFILINGREQUEST']._serialized_start=87
  _globals['_FILEPROFILINGREQUEST']._serialized_end=244
  _globals['_PROFILEREQUEST']._serialized_start=247
  _globals['_PROFILEREQUEST']._serialized_end=458
  _globals['_COLUMN']._serialized_start=460
  _globals['_COLUMN']._serialized_end=494
  _globals['_FILEPROFILINGRESPONSE']._serialized_start=497
  _globals['_FILEPROFILINGRESPONSE']._serialized_end=639
  _globals['_ROW']._serialized_start=641
  _globals['_ROW']._serialized_end=662
# @@protoc_insertion_point(module_scope)
