# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: common/configuration.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import auth_pb2 as common_dot_auth__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1a\x63ommon/configuration.proto\x12\x06\x63ommon\x1a\x11\x63ommon/auth.proto\".\n\x10\x41rrayOfTextParam\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x03(\t\"*\n\x0c\x42ooleanParam\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08\"\x7f\n\x0f\x44ictionaryParam\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x31\n\x05value\x18\x02 \x03(\x0b\x32\".common.DictionaryParam.ValueEntry\x1a,\n\nValueEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"2\n\x14\x45ncryptedBinaryParam\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c\"0\n\x12\x45ncryptedTextParam\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"(\n\nFloatParam\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x02\"*\n\x0cIntegerParam\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x05\"(\n\nRadioParam\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\")\n\x0bSelectParam\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"\'\n\tTextParam\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"+\n\rTextAreaParam\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"3\n\tAuthParam\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x19\n\x05value\x18\x02 \x01(\x0b\x32\n.auth.Auth\"\xaa\x04\n\x11ProtobufParameter\x12/\n\x0b\x61rrayOfText\x18\x01 \x01(\x0b\x32\x18.common.ArrayOfTextParamH\x00\x12\'\n\x07\x62oolean\x18\x02 \x01(\x0b\x32\x14.common.BooleanParamH\x00\x12-\n\ndictionary\x18\x03 \x01(\x0b\x32\x17.common.DictionaryParamH\x00\x12\x37\n\x0f\x65ncryptedBinary\x18\x04 \x01(\x0b\x32\x1c.common.EncryptedBinaryParamH\x00\x12\x33\n\rencryptedText\x18\x05 \x01(\x0b\x32\x1a.common.EncryptedTextParamH\x00\x12#\n\x05\x66loat\x18\x06 \x01(\x0b\x32\x12.common.FloatParamH\x00\x12\'\n\x07integer\x18\x07 \x01(\x0b\x32\x14.common.IntegerParamH\x00\x12!\n\x04text\x18\x08 \x01(\x0b\x32\x11.common.TextParamH\x00\x12)\n\x08textArea\x18\t \x01(\x0b\x32\x15.common.TextAreaParamH\x00\x12#\n\x05radio\x18\n \x01(\x0b\x32\x12.common.RadioParamH\x00\x12%\n\x06select\x18\x0b \x01(\x0b\x32\x13.common.SelectParamH\x00\x12!\n\x04\x61uth\x18\x0c \x01(\x0b\x32\x11.common.AuthParamH\x00\x42\x13\n\x11ProtobufParameter\"\xd4\x02\n\x15ProtobufConfiguration\x12\x41\n\nparameters\x18\x01 \x03(\x0b\x32-.common.ProtobufConfiguration.ParametersEntry\x12Y\n\x16interpolatedParameters\x18\x02 \x03(\x0b\x32\x39.common.ProtobufConfiguration.InterpolatedParametersEntry\x1aL\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12(\n\x05value\x18\x02 \x01(\x0b\x32\x19.common.ProtobufParameter:\x02\x38\x01\x1aO\n\x1bInterpolatedParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1f\n\x05value\x18\x02 \x01(\x0b\x32\x10.auth.CAGRequest:\x02\x38\x01\x42,\n\x17\x61lation.sdk.grpc.commonB\x06\x43ommonP\x01Z\x07\x63ommon/b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'common.configuration_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\027alation.sdk.grpc.commonB\006CommonP\001Z\007common/'
  _globals['_DICTIONARYPARAM_VALUEENTRY']._options = None
  _globals['_DICTIONARYPARAM_VALUEENTRY']._serialized_options = b'8\001'
  _globals['_PROTOBUFCONFIGURATION_PARAMETERSENTRY']._options = None
  _globals['_PROTOBUFCONFIGURATION_PARAMETERSENTRY']._serialized_options = b'8\001'
  _globals['_PROTOBUFCONFIGURATION_INTERPOLATEDPARAMETERSENTRY']._options = None
  _globals['_PROTOBUFCONFIGURATION_INTERPOLATEDPARAMETERSENTRY']._serialized_options = b'8\001'
  _globals['_ARRAYOFTEXTPARAM']._serialized_start=57
  _globals['_ARRAYOFTEXTPARAM']._serialized_end=103
  _globals['_BOOLEANPARAM']._serialized_start=105
  _globals['_BOOLEANPARAM']._serialized_end=147
  _globals['_DICTIONARYPARAM']._serialized_start=149
  _globals['_DICTIONARYPARAM']._serialized_end=276
  _globals['_DICTIONARYPARAM_VALUEENTRY']._serialized_start=232
  _globals['_DICTIONARYPARAM_VALUEENTRY']._serialized_end=276
  _globals['_ENCRYPTEDBINARYPARAM']._serialized_start=278
  _globals['_ENCRYPTEDBINARYPARAM']._serialized_end=328
  _globals['_ENCRYPTEDTEXTPARAM']._serialized_start=330
  _globals['_ENCRYPTEDTEXTPARAM']._serialized_end=378
  _globals['_FLOATPARAM']._serialized_start=380
  _globals['_FLOATPARAM']._serialized_end=420
  _globals['_INTEGERPARAM']._serialized_start=422
  _globals['_INTEGERPARAM']._serialized_end=464
  _globals['_RADIOPARAM']._serialized_start=466
  _globals['_RADIOPARAM']._serialized_end=506
  _globals['_SELECTPARAM']._serialized_start=508
  _globals['_SELECTPARAM']._serialized_end=549
  _globals['_TEXTPARAM']._serialized_start=551
  _globals['_TEXTPARAM']._serialized_end=590
  _globals['_TEXTAREAPARAM']._serialized_start=592
  _globals['_TEXTAREAPARAM']._serialized_end=635
  _globals['_AUTHPARAM']._serialized_start=637
  _globals['_AUTHPARAM']._serialized_end=688
  _globals['_PROTOBUFPARAMETER']._serialized_start=691
  _globals['_PROTOBUFPARAMETER']._serialized_end=1245
  _globals['_PROTOBUFCONFIGURATION']._serialized_start=1248
  _globals['_PROTOBUFCONFIGURATION']._serialized_end=1588
  _globals['_PROTOBUFCONFIGURATION_PARAMETERSENTRY']._serialized_start=1431
  _globals['_PROTOBUFCONFIGURATION_PARAMETERSENTRY']._serialized_end=1507
  _globals['_PROTOBUFCONFIGURATION_INTERPOLATEDPARAMETERSENTRY']._serialized_start=1509
  _globals['_PROTOBUFCONFIGURATION_INTERPOLATEDPARAMETERSENTRY']._serialized_end=1588
# @@protoc_insertion_point(module_scope)
