# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: common/job_error.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16\x63ommon/job_error.proto\x12\tjob_error\"*\n\x0c\x43ontextEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"\x9e\x01\n\x05\x45rror\x12\x0f\n\x07message\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08\x63\x61tegory\x18\x03 \x01(\t\x12\x0e\n\x06\x61\x63tion\x18\x04 \x01(\t\x12(\n\x07\x63ontext\x18\x05 \x03(\x0b\x32\x17.job_error.ContextEntry\x12*\n\x08severity\x18\x06 \x01(\x0e\x32\x18.job_error.ErrorSeverity*\'\n\rErrorSeverity\x12\x06\n\x02P0\x10\x00\x12\x06\n\x02P1\x10\x01\x12\x06\n\x02P2\x10\x02\x42\x41\n!alation.sdk.grpc.common.job_errorB\x08JobErrorP\x01Z\x10\x63ommon/job_errorb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'common.job_error_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n!alation.sdk.grpc.common.job_errorB\010JobErrorP\001Z\020common/job_error'
  _globals['_ERRORSEVERITY']._serialized_start=242
  _globals['_ERRORSEVERITY']._serialized_end=281
  _globals['_CONTEXTENTRY']._serialized_start=37
  _globals['_CONTEXTENTRY']._serialized_end=79
  _globals['_ERROR']._serialized_start=82
  _globals['_ERROR']._serialized_end=240
# @@protoc_insertion_point(module_scope)
