# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rdbms/mde.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from queryservice_client.protobuf.common import configuration_pb2 as common_dot_configuration__pb2
from queryservice_client.protobuf.common import extraction_objects_pb2 as common_dot_extraction__objects__pb2
from queryservice_client.protobuf.common import job_error_pb2 as common_dot_job__error__pb2
from queryservice_client.protobuf.rdbms import mde_objects_pb2 as rdbms_dot_mde__objects__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0frdbms/mde.proto\x12\trdbms.mde\x1a\x1a\x63ommon/configuration.proto\x1a\x1f\x63ommon/extraction_objects.proto\x1a\x16\x63ommon/job_error.proto\x1a\x17rdbms/mde_objects.proto\"O\n\x17\x46ilterExtractionRequest\x12\x34\n\rconfiguration\x18\x01 \x01(\x0b\x32\x1d.common.ProtobufConfiguration\"\xfc\x01\n\x18\x46ilterExtractionResponse\x12\x41\n\x11\x64\x61tabaseCatalogId\x18\x01 \x01(\x0b\x32$.rdbms.mde_objects.DatabaseCatalogIdH\x00\x12/\n\x08schemaId\x18\x02 \x01(\x0b\x32\x1b.rdbms.mde_objects.SchemaIdH\x00\x12-\n\x07tableId\x18\x03 \x01(\x0b\x32\x1a.rdbms.mde_objects.TableIdH\x00\x12!\n\x05\x65rror\x18\x04 \x01(\x0b\x32\x10.job_error.ErrorH\x00\x42\x1a\n\x18\x46ilterExtractionResponse\"\xd1\x01\n\x19MetadataExtractionRequest\x12\x34\n\rconfiguration\x18\x01 \x01(\x0b\x32\x1d.common.ProtobufConfiguration\x12\x33\n\x06\x66ilter\x18\x02 \x03(\x0b\x32#.rdbms.mde.FilterExtractionResponse\x12\x19\n\x11is_include_filter\x18\x03 \x01(\x08\x12.\n\x08\x62ookmark\x18\x04 \x01(\x0b\x32\x1c.extraction_objects.Bookmark\"q\n\x12\x45xtractionProgress\x12\x11\n\x07message\x18\x01 \x01(\tH\x00\x12\x32\n\x0e\x63ompletedOtype\x18\x02 \x01(\x0e\x32\x18.rdbms.mde_objects.OtypeH\x00\x42\x14\n\x12\x45xtractionProgress\"\xbe\x03\n\x1aMetadataExtractionResponse\x12=\n\x0f\x64\x61tabaseCatalog\x18\x01 \x01(\x0b\x32\".rdbms.mde_objects.DatabaseCatalogH\x00\x12+\n\x06schema\x18\x02 \x01(\x0b\x32\x19.rdbms.mde_objects.SchemaH\x00\x12)\n\x05table\x18\x03 \x01(\x0b\x32\x18.rdbms.mde_objects.TableH\x00\x12+\n\x06\x63olumn\x18\x04 \x01(\x0b\x32\x19.rdbms.mde_objects.ColumnH\x00\x12/\n\x08\x66unction\x18\x05 \x01(\x0b\x32\x1b.rdbms.mde_objects.FunctionH\x00\x12;\n\x12\x65xtractionProgress\x18\x06 \x01(\x0b\x32\x1d.rdbms.mde.ExtractionProgressH\x00\x12!\n\x05\x65rror\x18\x07 \x01(\x0b\x32\x10.job_error.ErrorH\x00\x12\x30\n\x08\x62ookmark\x18\x08 \x01(\x0b\x32\x1c.extraction_objects.BookmarkH\x00\x42\x19\n\x17\x45xtractMetadataResponse\"\xac\x01\n\x16TableExtractionRequest\x12\x34\n\rconfiguration\x18\x01 \x01(\x0b\x32\x1d.common.ProtobufConfiguration\x12+\n\x07tableId\x18\x02 \x01(\x0b\x32\x1a.rdbms.mde_objects.TableId\x12/\n\ttableType\x18\x03 \x01(\x0b\x32\x1c.rdbms.mde_objects.TableType\"\x8c\x01\n\x17TableExtractionResponse\x12)\n\x05table\x18\x01 \x01(\x0b\x32\x18.rdbms.mde_objects.TableH\x00\x12+\n\x06\x63olumn\x18\x02 \x01(\x0b\x32\x19.rdbms.mde_objects.ColumnH\x00\x42\x19\n\x17TableExtractionResponseB=\n\x1a\x61lation.sdk.rdbms.grpc.mdeB\x12MetadataExtractionP\x01Z\trdbms/mdeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'rdbms.mde_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\032alation.sdk.rdbms.grpc.mdeB\022MetadataExtractionP\001Z\trdbms/mde'
  _globals['_FILTEREXTRACTIONREQUEST']._serialized_start=140
  _globals['_FILTEREXTRACTIONREQUEST']._serialized_end=219
  _globals['_FILTEREXTRACTIONRESPONSE']._serialized_start=222
  _globals['_FILTEREXTRACTIONRESPONSE']._serialized_end=474
  _globals['_METADATAEXTRACTIONREQUEST']._serialized_start=477
  _globals['_METADATAEXTRACTIONREQUEST']._serialized_end=686
  _globals['_EXTRACTIONPROGRESS']._serialized_start=688
  _globals['_EXTRACTIONPROGRESS']._serialized_end=801
  _globals['_METADATAEXTRACTIONRESPONSE']._serialized_start=804
  _globals['_METADATAEXTRACTIONRESPONSE']._serialized_end=1250
  _globals['_TABLEEXTRACTIONREQUEST']._serialized_start=1253
  _globals['_TABLEEXTRACTIONREQUEST']._serialized_end=1425
  _globals['_TABLEEXTRACTIONRESPONSE']._serialized_start=1428
  _globals['_TABLEEXTRACTIONRESPONSE']._serialized_end=1568
# @@protoc_insertion_point(module_scope)
