# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cf/cf_sync.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cf import cf_objects_pb2 as cf_dot_cf__objects__pb2
from queryservice_client.protobuf.common import auth_pb2 as common_dot_auth__pb2
from queryservice_client.protobuf.common import configuration_pb2 as common_dot_configuration__pb2
from queryservice_client.protobuf.common import error_pb2 as common_dot_error__pb2
from queryservice_client.protobuf.rdbms import mde_objects_pb2 as rdbms_dot_mde__objects__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10\x63\x66/cf_sync.proto\x12\x0cocf.cf.rdbms\x1a\x13\x63\x66/cf_objects.proto\x1a\x11\x63ommon/auth.proto\x1a\x1a\x63ommon/configuration.proto\x1a\x12\x63ommon/error.proto\x1a\x17rdbms/mde_objects.proto\"\xe4\x01\n\x17\x43ustomFieldSyncResponse\x12/\n\x08schemaId\x18\x01 \x01(\x0b\x32\x1b.rdbms.mde_objects.SchemaIdH\x00\x12-\n\x07tableId\x18\x02 \x01(\x0b\x32\x1a.rdbms.mde_objects.TableIdH\x00\x12/\n\x08\x63olumnId\x18\x03 \x01(\x0b\x32\x1b.rdbms.mde_objects.ColumnIdH\x00\x12\x1d\n\x05\x65rror\x18\x04 \x01(\x0b\x32\x0c.error.ErrorH\x00\x42\x19\n\x17\x43ustomFieldSyncResponse\"\xb4\x01\n\x16\x43ustomFieldSyncRequest\x12\x34\n\rconfiguration\x18\x01 \x01(\x0b\x32\x1d.common.ProtobufConfiguration\x12\x18\n\x04\x61uth\x18\x02 \x01(\x0b\x32\n.auth.Auth\x12J\n\x17\x63ustomFieldValueUpdates\x18\x03 \x03(\x0b\x32).ocf.cf.cf_objects.CustomFieldValueUpdate2z\n\x14RdbmsCustomFieldSync\x12\x62\n\x0f\x43ustomFieldSync\x12$.ocf.cf.rdbms.CustomFieldSyncRequest\x1a%.ocf.cf.rdbms.CustomFieldSyncResponse\"\x00\x30\x01\x42)\n\x17\x61lation.sdk.ocf.cf.grpcB\x0cMetadataSyncP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cf.cf_sync_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\027alation.sdk.ocf.cf.grpcB\014MetadataSyncP\001'
  _globals['_CUSTOMFIELDSYNCRESPONSE']._serialized_start=148
  _globals['_CUSTOMFIELDSYNCRESPONSE']._serialized_end=376
  _globals['_CUSTOMFIELDSYNCREQUEST']._serialized_start=379
  _globals['_CUSTOMFIELDSYNCREQUEST']._serialized_end=559
  _globals['_RDBMSCUSTOMFIELDSYNC']._serialized_start=561
  _globals['_RDBMSCUSTOMFIELDSYNC']._serialized_end=683
# @@protoc_insertion_point(module_scope)
