# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: common/operations.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from queryservice_client.protobuf.common import checks_pb2 as common_dot_checks__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17\x63ommon/operations.proto\x12\nocf.common\x1a\x13\x63ommon/checks.proto2M\n\nOperations\x12?\n\x0ePreflightCheck\x12\x14.checks.CheckRequest\x1a\x13.checks.CheckResult\"\x00\x30\x01\x42N\n\"alation.sdk.grpc.common.operationsB\x13\x43onnectorOperationsP\x01Z\x11\x63ommon/operationsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'common.operations_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\"alation.sdk.grpc.common.operationsB\023ConnectorOperationsP\001Z\021common/operations'
  _globals['_OPERATIONS']._serialized_start=60
  _globals['_OPERATIONS']._serialized_end=137
# @@protoc_insertion_point(module_scope)
