# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fs/fs.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from queryservice_client.protobuf.common import verify_pb2 as common_dot_verify__pb2
from fs import mde_pb2 as fs_dot_mde__pb2
from fs import fs_profiling_pb2 as fs_dot_fs__profiling__pb2
from fs import volume_check_pb2 as fs_dot_volume__check__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0b\x66s/fs.proto\x12\x02\x66s\x1a\x1bgoogle/protobuf/empty.proto\x1a\x13\x63ommon/verify.proto\x1a\x0c\x66s/mde.proto\x1a\x15\x66s/fs_profiling.proto\x1a\x15\x66s/volume_check.proto2\xa9\x04\n\nFileSystem\x12\x46\n\x19\x43onfigurationVerification\x12\x0f.verify.Request\x1a\x16.google.protobuf.Empty\"\x00\x12Y\n\x10\x46ilterExtraction\x12\x1f.fs.mde.FilterExtractionRequest\x1a .fs.mde.FilterExtractionResponse\"\x00\x30\x01\x12_\n\x12MetadataExtraction\x12!.fs.mde.MetadataExtractionRequest\x1a\".fs.mde.MetadataExtractionResponse\"\x00\x30\x01\x12[\n\x10\x43olumnExtraction\x12!.fs.mde.MetadataExtractionRequest\x1a .fs.mde.ColumnExtractionResponse\"\x00\x30\x01\x12\\\n\rFileProfiling\x12\".fs.profiling.FileProfilingRequest\x1a#.fs.profiling.FileProfilingResponse\"\x00\x30\x01\x12\\\n\x0bVolumeCheck\x12#.fs.volume_check.VolumeCheckRequest\x1a$.fs.volume_check.VolumeCheckResponse\"\x00\x30\x01\x42%\n\x13\x61lation.sdk.fs.grpcB\x07\x46SProtoP\x01Z\x03\x66s/b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'fs.fs_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\023alation.sdk.fs.grpcB\007FSProtoP\001Z\003fs/'
  _globals['_FILESYSTEM']._serialized_start=130
  _globals['_FILESYSTEM']._serialized_end=683
# @@protoc_insertion_point(module_scope)
