# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: policy/policy_objects.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from queryservice_client.protobuf.rdbms import mde_objects_pb2 as rdbms_dot_mde__objects__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bpolicy/policy_objects.proto\x12\x19ocf.policy.policy_objects\x1a\x17rdbms/mde_objects.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\x19\n\x08PolicyId\x12\r\n\x05parts\x18\x01 \x03(\t\"w\n\x0bPolicyApiId\x12<\n\x03key\x18\x01 \x03(\x0b\x32/.ocf.policy.policy_objects.PolicyApiId.KeyEntry\x1a*\n\x08KeyEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"/\n\rSQLDefinition\x12\x0b\n\x03sql\x18\x01 \x01(\t\x12\x11\n\targuments\x18\x02 \x03(\t\"\xec\x02\n\x06Policy\x12/\n\x02id\x18\x01 \x01(\x0b\x32#.ocf.policy.policy_objects.PolicyId\x12\x35\n\x05\x61piId\x18\x02 \x01(\x0b\x32&.ocf.policy.policy_objects.PolicyApiId\x12\x0c\n\x04name\x18\x03 \x01(\t\x12@\n\npolicyType\x18\x04 \x01(\x0e\x32,.ocf.policy.policy_objects.Policy.PolicyType\x12\r\n\x05owner\x18\x05 \x01(\t\x12-\n\ttsCreated\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12?\n\rsqlDefinition\x18\x07 \x01(\x0b\x32(.ocf.policy.policy_objects.SQLDefinition\"+\n\nPolicyType\x12\r\n\tDATA_MASK\x10\x00\x12\x0e\n\nROW_ACCESS\x10\x01\"j\n\tTableLink\x12\x30\n\x03pid\x18\x01 \x01(\x0b\x32#.ocf.policy.policy_objects.PolicyId\x12+\n\x07tableId\x18\x02 \x01(\x0b\x32\x1a.rdbms.mde_objects.TableId\"m\n\nColumnLink\x12\x30\n\x03pid\x18\x01 \x01(\x0b\x32#.ocf.policy.policy_objects.PolicyId\x12-\n\x08\x63olumnId\x18\x02 \x01(\x0b\x32\x1b.rdbms.mde_objects.ColumnId\"\x8e\x01\n\x11PolicyObjectApiId\x12\x33\n\ntableApiId\x18\x01 \x01(\x0b\x32\x1d.rdbms.mde_objects.TableApiIdH\x00\x12\x35\n\x0b\x63olumnApiId\x18\x02 \x01(\x0b\x32\x1e.rdbms.mde_objects.ColumnApiIdH\x00\x42\r\n\x0bobjectApiId\"Q\n\x0ePolicyArgument\x12\x10\n\x08\x61rgument\x18\x01 \x01(\t\x12-\n\x08\x63olumnId\x18\x02 \x01(\x0b\x32\x1b.rdbms.mde_objects.ColumnId\"\xa4\x01\n\x15PolicyObjectSyncValue\x12G\n\x11policyObjectApiId\x18\x01 \x01(\x0b\x32,.ocf.policy.policy_objects.PolicyObjectApiId\x12\x42\n\x0fpolicyArguments\x18\x02 \x03(\x0b\x32).ocf.policy.policy_objects.PolicyArgumentB:\n\x1f\x61lation.sdk.ocf.policy.grpc.mdeB\x15PolicyMetadataObjectsP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'policy.policy_objects_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\037alation.sdk.ocf.policy.grpc.mdeB\025PolicyMetadataObjectsP\001'
  _globals['_POLICYAPIID_KEYENTRY']._options = None
  _globals['_POLICYAPIID_KEYENTRY']._serialized_options = b'8\001'
  _globals['_POLICYID']._serialized_start=116
  _globals['_POLICYID']._serialized_end=141
  _globals['_POLICYAPIID']._serialized_start=143
  _globals['_POLICYAPIID']._serialized_end=262
  _globals['_POLICYAPIID_KEYENTRY']._serialized_start=220
  _globals['_POLICYAPIID_KEYENTRY']._serialized_end=262
  _globals['_SQLDEFINITION']._serialized_start=264
  _globals['_SQLDEFINITION']._serialized_end=311
  _globals['_POLICY']._serialized_start=314
  _globals['_POLICY']._serialized_end=678
  _globals['_POLICY_POLICYTYPE']._serialized_start=635
  _globals['_POLICY_POLICYTYPE']._serialized_end=678
  _globals['_TABLELINK']._serialized_start=680
  _globals['_TABLELINK']._serialized_end=786
  _globals['_COLUMNLINK']._serialized_start=788
  _globals['_COLUMNLINK']._serialized_end=897
  _globals['_POLICYOBJECTAPIID']._serialized_start=900
  _globals['_POLICYOBJECTAPIID']._serialized_end=1042
  _globals['_POLICYARGUMENT']._serialized_start=1044
  _globals['_POLICYARGUMENT']._serialized_end=1125
  _globals['_POLICYOBJECTSYNCVALUE']._serialized_start=1128
  _globals['_POLICYOBJECTSYNCVALUE']._serialized_end=1292
# @@protoc_insertion_point(module_scope)
