# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bi/mde.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from queryservice_client.protobuf.common import configuration_pb2 as common_dot_configuration__pb2
from queryservice_client.protobuf.common import job_error_pb2 as common_dot_job__error__pb2
from bi import mde_objects_pb2 as bi_dot_mde__objects__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0c\x62i/mde.proto\x12\x06\x62i.mde\x1a\x1a\x63ommon/configuration.proto\x1a\x16\x63ommon/job_error.proto\x1a\x14\x62i/mde_objects.proto\"y\n\x15ListFileSystemRequest\x12\x34\n\rconfiguration\x18\x01 \x01(\x0b\x32\x1d.common.ProtobufConfiguration\x12*\n\x05users\x18\x02 \x03(\x0b\x32\x1b.bi.mde_objects.AlationUser\"\xc3\x01\n\x18RunFullExtractionRequest\x12\x34\n\rconfiguration\x18\x01 \x01(\x0b\x32\x1d.common.ProtobufConfiguration\x12,\n\x07\x66olders\x18\x02 \x03(\x0b\x32\x1b.bi.mde_objects.GBMBIFolder\x12\x17\n\x0fisIncludeFilter\x18\x03 \x01(\x08\x12*\n\x05users\x18\x04 \x03(\x0b\x32\x1b.bi.mde_objects.AlationUser\"\xf9\x04\n\x10\x42IObjectResponse\x12+\n\x06\x62iUser\x18\x01 \x01(\x0b\x32\x19.bi.mde_objects.GBMBIUserH\x00\x12/\n\x08\x62iFolder\x18\x02 \x01(\x0b\x32\x1b.bi.mde_objects.GBMBIFolderH\x00\x12/\n\x08\x62iReport\x18\x03 \x01(\x0b\x32\x1b.bi.mde_objects.GBMBIReportH\x00\x12\x37\n\x0c\x62iDataSource\x18\x04 \x01(\x0b\x32\x1f.bi.mde_objects.GBMBIDatasourceH\x00\x12\x37\n\x0c\x62iConnection\x18\x05 \x01(\x0b\x32\x1f.bi.mde_objects.GBMBIConnectionH\x00\x12;\n\x0e\x62iReportColumn\x18\x06 \x01(\x0b\x32!.bi.mde_objects.GBMBIReportColumnH\x00\x12\x43\n\x12\x62iDatasourceColumn\x18\x07 \x01(\x0b\x32%.bi.mde_objects.GBMBIDatasourceColumnH\x00\x12\x43\n\x12\x62iConnectionColumn\x18\x08 \x01(\x0b\x32%.bi.mde_objects.GBMBIConnectionColumnH\x00\x12\x37\n\x0c\x62iPermission\x18\t \x01(\x0b\x32\x1f.bi.mde_objects.GBMBIPermissionH\x00\x12-\n\x07\x62iImage\x18\n \x01(\x0b\x32\x1a.bi.mde_objects.GBMBIImageH\x00\x12!\n\x05\x65rror\x18\x0b \x01(\x0b\x32\x10.job_error.ErrorH\x00\x42\x12\n\x10\x62iObjectResponseB/\n\x17\x61lation.sdk.bi.grpc.mdeB\x12MetadataExtractionP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bi.mde_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\027alation.sdk.bi.grpc.mdeB\022MetadataExtractionP\001'
  _globals['_LISTFILESYSTEMREQUEST']._serialized_start=98
  _globals['_LISTFILESYSTEMREQUEST']._serialized_end=219
  _globals['_RUNFULLEXTRACTIONREQUEST']._serialized_start=222
  _globals['_RUNFULLEXTRACTIONREQUEST']._serialized_end=417
  _globals['_BIOBJECTRESPONSE']._serialized_start=420
  _globals['_BIOBJECTRESPONSE']._serialized_end=1053
# @@protoc_insertion_point(module_scope)
