# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dl/dl_elt.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from queryservice_client.protobuf.common import configuration_pb2 as common_dot_configuration__pb2
from dl import dl_objects_pb2 as dl_dot_dl__objects__pb2
from queryservice_client.protobuf.common import job_error_pb2 as common_dot_job__error__pb2
from queryservice_client.protobuf.common import extraction_objects_pb2 as common_dot_extraction__objects__pb2
from asset import filter_extraction_pb2 as asset_dot_filter__extraction__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0f\x64l/dl_elt.proto\x12\nocf.dl.elt\x1a\x1a\x63ommon/configuration.proto\x1a\x13\x64l/dl_objects.proto\x1a\x16\x63ommon/job_error.proto\x1a\x1f\x63ommon/extraction_objects.proto\x1a\x1d\x61sset/filter_extraction.proto\"\xb0\x02\n\x18LineageExtractionRequest\x12\x34\n\rconfiguration\x18\x01 \x01(\x0b\x32\x1d.common.ProtobufConfiguration\x12\x15\n\rhasAllLineage\x18\x02 \x01(\x08\x12\x30\n\rprojectDetail\x18\x03 \x03(\x0b\x32\x19.ocf.dl.elt.ProjectDetail\x12\x33\n\x08\x62ookmark\x18\x04 \x03(\x0b\x32!.extraction_objects.KeyedBookmark\x12\x45\n\x06\x66ilter\x18\x05 \x03(\x0b\x32\x35.ocf.asset.filter_extraction.FilterExtractionResponse\x12\x19\n\x11isInclusionFilter\x18\x06 \x01(\x08\"\x9e\x03\n\rProjectDetail\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x12\n\nexternalId\x18\x02 \x01(\t\x12\x14\n\x0c\x64\x61tabaseType\x18\x03 \x01(\t\x12\x45\n\x0e\x61\x64\x64itionalInfo\x18\x04 \x03(\x0b\x32-.ocf.dl.elt.ProjectDetail.AdditionalInfoEntry\x12W\n\x17\x64\x61tasourceConfiguration\x18\x05 \x03(\x0b\x32\x36.ocf.dl.elt.ProjectDetail.DatasourceConfigurationEntry\x12>\n\x14primaryConnectorInfo\x18\x06 \x01(\x0b\x32 .ocf.dl.elt.PrimaryConnectorInfo\x1a\x35\n\x13\x41\x64\x64itionalInfoEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a>\n\x1c\x44\x61tasourceConfigurationEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"2\n\x14PrimaryConnectorInfo\x12\x0c\n\x04host\x18\x01 \x01(\t\x12\x0c\n\x04port\x18\x02 \x01(\x05\"\x9b\x02\n\x19LineageExtractionResponse\x12\x41\n\x0blineagePath\x18\x01 \x01(\x0b\x32*.ocf.dl.direct_lineage_objects.LineagePathH\x00\x12\x35\n\x08\x62ookmark\x18\x02 \x01(\x0b\x32!.extraction_objects.KeyedBookmarkH\x00\x12!\n\x05\x65rror\x18\x03 \x01(\x0b\x32\x10.job_error.ErrorH\x00\x12\x44\n\x12\x65xtractionProgress\x18\x04 \x01(\x0b\x32&.extraction_objects.ExtractionProgressH\x00\x42\x1b\n\x19LineageExtractionResponse2y\n\x11LineageExtraction\x12\x64\n\x11LineageExtraction\x12$.ocf.dl.elt.LineageExtractionRequest\x1a%.ocf.dl.elt.LineageExtractionResponse\"\x00\x30\x01\x42;\n\x1b\x61lation.sdk.ocf.dl.elt.grpcB\x1a\x45ltDirectLineageExtractionP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dl.dl_elt_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033alation.sdk.ocf.dl.elt.grpcB\032EltDirectLineageExtractionP\001'
  _globals['_PROJECTDETAIL_ADDITIONALINFOENTRY']._options = None
  _globals['_PROJECTDETAIL_ADDITIONALINFOENTRY']._serialized_options = b'8\001'
  _globals['_PROJECTDETAIL_DATASOURCECONFIGURATIONENTRY']._options = None
  _globals['_PROJECTDETAIL_DATASOURCECONFIGURATIONENTRY']._serialized_options = b'8\001'
  _globals['_LINEAGEEXTRACTIONREQUEST']._serialized_start=169
  _globals['_LINEAGEEXTRACTIONREQUEST']._serialized_end=473
  _globals['_PROJECTDETAIL']._serialized_start=476
  _globals['_PROJECTDETAIL']._serialized_end=890
  _globals['_PROJECTDETAIL_ADDITIONALINFOENTRY']._serialized_start=773
  _globals['_PROJECTDETAIL_ADDITIONALINFOENTRY']._serialized_end=826
  _globals['_PROJECTDETAIL_DATASOURCECONFIGURATIONENTRY']._serialized_start=828
  _globals['_PROJECTDETAIL_DATASOURCECONFIGURATIONENTRY']._serialized_end=890
  _globals['_PRIMARYCONNECTORINFO']._serialized_start=892
  _globals['_PRIMARYCONNECTORINFO']._serialized_end=942
  _globals['_LINEAGEEXTRACTIONRESPONSE']._serialized_start=945
  _globals['_LINEAGEEXTRACTIONRESPONSE']._serialized_end=1228
  _globals['_LINEAGEEXTRACTION']._serialized_start=1230
  _globals['_LINEAGEEXTRACTION']._serialized_end=1351
# @@protoc_insertion_point(module_scope)
