# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: asset/mde_objects.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17\x61sset/mde_objects.proto\x12\x15ocf.asset.mde_objects\x1a\x1cgoogle/protobuf/struct.proto\"\xa3\x01\n\x05\x41sset\x12.\n\x03\x65id\x18\x01 \x01(\x0b\x32!.ocf.asset.mde_objects.ExternalID\x12\x35\n\nparent_eid\x18\x02 \x01(\x0b\x32!.ocf.asset.mde_objects.ExternalID\x12\x33\n\nproperties\x18\x65 \x03(\x0b\x32\x1f.ocf.asset.mde_objects.Property\"?\n\nExternalID\x12\x10\n\x08\x61type_id\x18\x01 \x01(\t\x12\x12\n\natype_name\x18\x02 \x01(\t\x12\x0b\n\x03\x65id\x18\x03 \x01(\t\".\n\x10RelationMetadata\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04role\x18\x02 \x01(\t\"\xc4\x02\n\x08Property\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x41\n\x10relationMetadata\x18\x02 \x01(\x0b\x32\'.ocf.asset.mde_objects.RelationMetadata\x12\x12\n\x08string_v\x18\x64 \x01(\tH\x00\x12,\n\x06list_v\x18\x65 \x01(\x0b\x32\x1a.google.protobuf.ListValueH\x00\x12\x11\n\x07int32_v\x18\x66 \x01(\x05H\x00\x12\x11\n\x07int64_v\x18g \x01(\x03H\x00\x12\x10\n\x06\x62ool_v\x18h \x01(\x08H\x00\x12\x30\n\x07\x61sset_v\x18\xc8\x01 \x01(\x0b\x32\x1c.ocf.asset.mde_objects.AssetH\x00\x12\x32\n\x08\x61ssets_v\x18\xc9\x01 \x01(\x0b\x32\x1d.ocf.asset.mde_objects.AssetsH\x00\x42\x07\n\x05value\"6\n\x06\x41ssets\x12,\n\x06\x61ssets\x18\x01 \x03(\x0b\x32\x1c.ocf.asset.mde_objects.Asset\"\x99\x02\n\x0e\x44QRuleAndValue\x12\x12\n\nexternalID\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12+\n\x05\x61sset\x18\x05 \x01(\x0b\x32\x1c.ocf.asset.mde_objects.Asset\x12/\n\x06status\x18\x06 \x01(\x0e\x32\x1f.ocf.asset.mde_objects.DQStatus\x12\x12\n\x08string_v\x18\x64 \x01(\tH\x00\x12\x11\n\x07int32_v\x18\x65 \x01(\x05H\x00\x12\x10\n\x06\x62ool_v\x18\x66 \x01(\x08H\x00\x12\x0b\n\x03url\x18\x07 \x01(\t\x12\x15\n\rlastUpdatedAt\x18\x08 \x01(\tB\x07\n\x05value*,\n\x08\x44QStatus\x12\x08\n\x04GOOD\x10\x00\x12\x0b\n\x07WARNING\x10\x01\x12\t\n\x05\x41LERT\x10\x02\x42\x42\n\x1a\x61lation.sdk.asset.grpc.mdeB\x0fMetadataObjectsP\x01Z\x11\x61sset/mde_objectsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'asset.mde_objects_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\032alation.sdk.asset.grpc.mdeB\017MetadataObjectsP\001Z\021asset/mde_objects'
  _globals['_DQSTATUS']._serialized_start=1026
  _globals['_DQSTATUS']._serialized_end=1070
  _globals['_ASSET']._serialized_start=81
  _globals['_ASSET']._serialized_end=244
  _globals['_EXTERNALID']._serialized_start=246
  _globals['_EXTERNALID']._serialized_end=309
  _globals['_RELATIONMETADATA']._serialized_start=311
  _globals['_RELATIONMETADATA']._serialized_end=357
  _globals['_PROPERTY']._serialized_start=360
  _globals['_PROPERTY']._serialized_end=684
  _globals['_ASSETS']._serialized_start=686
  _globals['_ASSETS']._serialized_end=740
  _globals['_DQRULEANDVALUE']._serialized_start=743
  _globals['_DQRULEANDVALUE']._serialized_end=1024
# @@protoc_insertion_point(module_scope)
