# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: servicediscovery/servicediscovery.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'servicediscovery/servicediscovery.proto\x12\x10servicediscovery\"\x15\n\x05\x41gent\x12\x0c\n\x04uuid\x18\x01 \x01(\t\"\x1c\n\tProxyList\x12\x0f\n\x07proxies\x18\x01 \x03(\t2d\n\x15ProxyServiceDiscovery\x12K\n\x11ResolveProxiesFor\x12\x17.servicediscovery.Agent\x1a\x1b.servicediscovery.ProxyList\"\x00\x42=\n\'alation.sdk.ocf.system.servicediscoveryB\x10ServiceDiscoveryP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'servicediscovery.servicediscovery_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\'alation.sdk.ocf.system.servicediscoveryB\020ServiceDiscoveryP\001'
  _globals['_AGENT']._serialized_start=61
  _globals['_AGENT']._serialized_end=82
  _globals['_PROXYLIST']._serialized_start=84
  _globals['_PROXYLIST']._serialized_end=112
  _globals['_PROXYSERVICEDISCOVERY']._serialized_start=114
  _globals['_PROXYSERVICEDISCOVERY']._serialized_end=214
# @@protoc_insertion_point(module_scope)
