# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: asset/filter_extraction_objects.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%asset/filter_extraction_objects.proto\x12#ocf.asset.filter_extraction_objects\"\xe6\x01\n\x06\x46ilter\x12\x13\n\x0b\x65xternal_id\x18\x01 \x01(\t\x12\x37\n\x04path\x18\x02 \x01(\x0b\x32).ocf.asset.filter_extraction_objects.Path\x12W\n\x0e\x61\x64\x64itionalInfo\x18\x03 \x03(\x0b\x32?.ocf.asset.filter_extraction_objects.Filter.AdditionalInfoEntry\x1a\x35\n\x13\x41\x64\x64itionalInfoEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\'\n\x04Path\x12\x0c\n\x04path\x18\x01 \x03(\t\x12\x11\n\tdelimiter\x18\x02 \x01(\tBf\n(alation.sdk.asset.grpc.filter_extractionB\x17\x46ilterExtractionObjectsP\x01Z\x1f\x61sset/filter_extraction_objectsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'asset.filter_extraction_objects_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n(alation.sdk.asset.grpc.filter_extractionB\027FilterExtractionObjectsP\001Z\037asset/filter_extraction_objects'
  _globals['_FILTER_ADDITIONALINFOENTRY']._options = None
  _globals['_FILTER_ADDITIONALINFOENTRY']._serialized_options = b'8\001'
  _globals['_FILTER']._serialized_start=79
  _globals['_FILTER']._serialized_end=309
  _globals['_FILTER_ADDITIONALINFOENTRY']._serialized_start=256
  _globals['_FILTER_ADDITIONALINFOENTRY']._serialized_end=309
  _globals['_PATH']._serialized_start=311
  _globals['_PATH']._serialized_end=350
# @@protoc_insertion_point(module_scope)
