# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dl/dl_rdbms.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from dl import dl_objects_pb2 as dl_dot_dl__objects__pb2
from queryservice_client.protobuf.rdbms import mde_pb2 as rdbms_dot_mde__pb2
from queryservice_client.protobuf.rdbms import mde_objects_pb2 as rdbms_dot_mde__objects__pb2
from queryservice_client.protobuf.common import configuration_pb2 as common_dot_configuration__pb2
from queryservice_client.protobuf.common import extraction_objects_pb2 as common_dot_extraction__objects__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11\x64l/dl_rdbms.proto\x12\x0cocf.dl.rdbms\x1a\x13\x64l/dl_objects.proto\x1a\x0frdbms/mde.proto\x1a\x17rdbms/mde_objects.proto\x1a\x1a\x63ommon/configuration.proto\x1a\x1f\x63ommon/extraction_objects.proto\"\xcb\x01\n\x18LineageExtractionRequest\x12\x34\n\rconfiguration\x18\x01 \x01(\x0b\x32\x1d.common.ProtobufConfiguration\x12.\n\tschemaIds\x18\x02 \x03(\x0b\x32\x1b.rdbms.mde_objects.SchemaId\x12\x19\n\x11is_include_filter\x18\x03 \x01(\x08\x12.\n\x08\x62ookmark\x18\x04 \x01(\x0b\x32\x1c.extraction_objects.Bookmark\"\x98\x01\n\x19LineageExtractionResponse\x12\x41\n\x0blineagePath\x18\x02 \x01(\x0b\x32*.ocf.dl.direct_lineage_objects.LineagePathH\x00\x12\x30\n\x08\x62ookmark\x18\x03 \x01(\x0b\x32\x1c.extraction_objects.BookmarkH\x00\x42\x06\n\x04\x64\x61ta2~\n\x12RdbmsDirectLineage\x12h\n\x11LineageExtraction\x12&.ocf.dl.rdbms.LineageExtractionRequest\x1a\'.ocf.dl.rdbms.LineageExtractionResponse\"\x00\x30\x01\x42\x34\n\x17\x61lation.sdk.ocf.dl.grpcB\x17\x44irectLineageExtractionP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dl.dl_rdbms_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\027alation.sdk.ocf.dl.grpcB\027DirectLineageExtractionP\001'
  _globals['_LINEAGEEXTRACTIONREQUEST']._serialized_start=160
  _globals['_LINEAGEEXTRACTIONREQUEST']._serialized_end=363
  _globals['_LINEAGEEXTRACTIONRESPONSE']._serialized_start=366
  _globals['_LINEAGEEXTRACTIONRESPONSE']._serialized_end=518
  _globals['_RDBMSDIRECTLINEAGE']._serialized_start=520
  _globals['_RDBMSDIRECTLINEAGE']._serialized_end=646
# @@protoc_insertion_point(module_scope)
