# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: common/auth.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11\x63ommon/auth.proto\x12\x04\x61uth\x1a\x1bgoogle/protobuf/empty.proto\"\xc2\x02\n\x04\x41uth\x12&\n\x04none\x18\x64 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x12\x1e\n\x06simple\x18\x65 \x01(\x0b\x32\x0c.auth.SimpleH\x00\x12\x1c\n\x05oauth\x18\x66 \x01(\x0b\x32\x0b.auth.OAuthH\x00\x12*\n\x0coauthRefresh\x18g \x01(\x0b\x32\x12.auth.OAuthRefreshH\x00\x12\"\n\x08\x61wsBasic\x18h \x01(\x0b\x32\x0e.auth.AwsBasicH\x00\x12&\n\nawsSession\x18i \x01(\x0b\x32\x10.auth.AwsSessionH\x00\x12&\n\nazureBasic\x18j \x01(\x0b\x32\x10.auth.AzureBasicH\x00\x12\'\n\x0crefreshToken\x18\x84\x07 \x01(\x0b\x32\x10.auth.CAGRequestB\x0b\n\tmechanism\",\n\x06Simple\x12\x10\n\x08username\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\t\"L\n\x05OAuth\x12\x13\n\x0b\x61\x63\x63\x65ssToken\x18\x01 \x01(\t\x12\x11\n\texpiresIn\x18\x02 \x01(\x05\x12\x0e\n\x06\x65xpiry\x18\x03 \x01(\x03\x12\x0b\n\x03uri\x18\x04 \x01(\t\"L\n\x0cOAuthRefresh\x12\x14\n\x0crefreshToken\x18\x01 \x01(\t\x12\x10\n\x08\x63lientId\x18\x02 \x01(\t\x12\x14\n\x0c\x63lientSecret\x18\x03 \x01(\t\"0\n\x08\x41wsBasic\x12\x11\n\taccessKey\x18\x01 \x01(\t\x12\x11\n\tsecretKey\x18\x02 \x01(\t\"l\n\nAwsSession\x12\x11\n\taccessKey\x18\x01 \x01(\t\x12\x11\n\tsecretKey\x18\x02 \x01(\t\x12\x14\n\x0csessionToken\x18\x03 \x01(\t\x12\x12\n\ndbUserName\x18\x04 \x01(\t\x12\x0e\n\x06\x65xpiry\x18\x05 \x01(\x03\".\n\nAzureBasic\x12\r\n\x05isSAS\x18\x01 \x01(\x08\x12\x11\n\taccessKey\x18\x02 \x01(\t\"F\n\nCAGRequest\x12\x10\n\x08hostname\x18\x01 \x01(\t\x12\r\n\x05token\x18\x02 \x01(\t\x12\x17\n\x0f\x65\x61gerInitialize\x18\x03 \x01(\x08\x42=\n\x1c\x61lation.sdk.grpc.common.authB\x0e\x41uthenticationP\x01Z\x0b\x63ommon/authb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'common.auth_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\034alation.sdk.grpc.common.authB\016AuthenticationP\001Z\013common/auth'
  _globals['_AUTH']._serialized_start=57
  _globals['_AUTH']._serialized_end=379
  _globals['_SIMPLE']._serialized_start=381
  _globals['_SIMPLE']._serialized_end=425
  _globals['_OAUTH']._serialized_start=427
  _globals['_OAUTH']._serialized_end=503
  _globals['_OAUTHREFRESH']._serialized_start=505
  _globals['_OAUTHREFRESH']._serialized_end=581
  _globals['_AWSBASIC']._serialized_start=583
  _globals['_AWSBASIC']._serialized_end=631
  _globals['_AWSSESSION']._serialized_start=633
  _globals['_AWSSESSION']._serialized_end=741
  _globals['_AZUREBASIC']._serialized_start=743
  _globals['_AZUREBASIC']._serialized_end=789
  _globals['_CAGREQUEST']._serialized_start=791
  _globals['_CAGREQUEST']._serialized_end=861
# @@protoc_insertion_point(module_scope)
