# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dl/dl_elt_project_extraction.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from queryservice_client.protobuf.common import configuration_pb2 as common_dot_configuration__pb2
from queryservice_client.protobuf.common import extraction_objects_pb2 as common_dot_extraction__objects__pb2
from queryservice_client.protobuf.common import job_error_pb2 as common_dot_job__error__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"dl/dl_elt_project_extraction.proto\x12\x19ocf.dl.project_extraction\x1a\x1a\x63ommon/configuration.proto\x1a\x1f\x63ommon/extraction_objects.proto\x1a\x16\x63ommon/job_error.proto\"P\n\x18ProjectExtractionRequest\x12\x34\n\rconfiguration\x18\x01 \x01(\x0b\x32\x1d.common.ProtobufConfiguration\"\xd8\x01\n\x19ProjectExtractionResponse\x12\x35\n\x07Project\x18\x01 \x01(\x0b\x32\".ocf.dl.project_extraction.ProjectH\x00\x12\x44\n\x12\x65xtractionProgress\x18\x02 \x01(\x0b\x32&.extraction_objects.ExtractionProgressH\x00\x12!\n\x05\x65rror\x18\x03 \x01(\x0b\x32\x10.job_error.ErrorH\x00\x42\x1b\n\x19ProjectExtractionResponse\"\xbc\x02\n\x07Project\x12\x12\n\nexternalId\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x14\n\x0c\x64\x61tabaseType\x18\x03 \x01(\t\x12;\n\x0blineageInfo\x18\x04 \x01(\x0b\x32&.ocf.dl.project_extraction.LineageInfo\x12\x35\n\x08hostInfo\x18\x05 \x01(\x0b\x32#.ocf.dl.project_extraction.HostInfo\x12N\n\x0e\x61\x64\x64itionalInfo\x18\x06 \x03(\x0b\x32\x36.ocf.dl.project_extraction.Project.AdditionalInfoEntry\x1a\x35\n\x13\x41\x64\x64itionalInfoEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"V\n\x0bLineageInfo\x12\x1c\n\x14primaryConnectorName\x18\x01 \x01(\t\x12\x15\n\rhasAllLineage\x18\x02 \x01(\x08\x12\x12\n\nhasLineage\x18\x03 \x01(\x08\"&\n\x08HostInfo\x12\x0c\n\x04host\x18\x01 \x01(\t\x12\x0c\n\x04port\x18\x02 \x01(\x05\x32\x98\x01\n\x11ProjectExtraction\x12\x82\x01\n\x11ProjectExtraction\x12\x33.ocf.dl.project_extraction.ProjectExtractionRequest\x1a\x34.ocf.dl.project_extraction.ProjectExtractionResponse\"\x00\x30\x01\x42\x34\n$alation.sdk.ocf.dl.elt.projects.grpcB\nEltProjectP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dl.dl_elt_project_extraction_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n$alation.sdk.ocf.dl.elt.projects.grpcB\nEltProjectP\001'
  _globals['_PROJECT_ADDITIONALINFOENTRY']._options = None
  _globals['_PROJECT_ADDITIONALINFOENTRY']._serialized_options = b'8\001'
  _globals['_PROJECTEXTRACTIONREQUEST']._serialized_start=150
  _globals['_PROJECTEXTRACTIONREQUEST']._serialized_end=230
  _globals['_PROJECTEXTRACTIONRESPONSE']._serialized_start=233
  _globals['_PROJECTEXTRACTIONRESPONSE']._serialized_end=449
  _globals['_PROJECT']._serialized_start=452
  _globals['_PROJECT']._serialized_end=768
  _globals['_PROJECT_ADDITIONALINFOENTRY']._serialized_start=715
  _globals['_PROJECT_ADDITIONALINFOENTRY']._serialized_end=768
  _globals['_LINEAGEINFO']._serialized_start=770
  _globals['_LINEAGEINFO']._serialized_end=856
  _globals['_HOSTINFO']._serialized_start=858
  _globals['_HOSTINFO']._serialized_end=896
  _globals['_PROJECTEXTRACTION']._serialized_start=899
  _globals['_PROJECTEXTRACTION']._serialized_end=1051
# @@protoc_insertion_point(module_scope)
