# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dl/dl_objects.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from queryservice_client.protobuf.rdbms import mde_objects_pb2 as rdbms_dot_mde__objects__pb2
from queryservice_client.protobuf.common import datasource_pb2 as common_dot_datasource__pb2
from asset import filter_extraction_objects_pb2 as asset_dot_filter__extraction__objects__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13\x64l/dl_objects.proto\x12\x1docf.dl.direct_lineage_objects\x1a\x17rdbms/mde_objects.proto\x1a\x17\x63ommon/datasource.proto\x1a%asset/filter_extraction_objects.proto\"Z\n\x08\x44\x61taflow\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\t\x12=\n\x06\x66\x61\x63\x65ts\x18\x02 \x01(\x0b\x32-.ocf.dl.direct_lineage_objects.DataflowFacets\"\xd7\x02\n\x0cNativeObject\x12+\n\x0b\x64\x61ta_source\x18\x01 \x01(\x0b\x32\x16.datasource.DataSource\x12\x30\n\tschema_id\x18\x02 \x01(\x0b\x32\x1b.rdbms.mde_objects.SchemaIdH\x00\x12.\n\x08table_id\x18\x03 \x01(\x0b\x32\x1a.rdbms.mde_objects.TableIdH\x00\x12\x30\n\tcolumn_id\x18\x04 \x01(\x0b\x32\x1b.rdbms.mde_objects.ColumnIdH\x00\x12\x38\n\x07path_id\x18\x06 \x01(\x0b\x32%.ocf.dl.direct_lineage_objects.PathIdH\x00\x12?\n\x06\x66\x61\x63\x65ts\x18\x05 \x01(\x0b\x32/.ocf.dl.direct_lineage_objects.DatasourceFacetsB\x0b\n\tObjectKey\"_\n\rLineageObject\x12\x44\n\rnative_object\x18\x01 \x01(\x0b\x32+.ocf.dl.direct_lineage_objects.NativeObjectH\x00\x42\x08\n\x06Object\"\x88\x02\n\x0bLineagePath\x12=\n\x07sources\x18\x01 \x03(\x0b\x32,.ocf.dl.direct_lineage_objects.LineageObject\x12\x39\n\x08\x64\x61taflow\x18\x02 \x01(\x0b\x32\'.ocf.dl.direct_lineage_objects.Dataflow\x12<\n\x06target\x18\x03 \x01(\x0b\x32,.ocf.dl.direct_lineage_objects.LineageObject\x12\x41\n\x12\x66ullyQualifiedPath\x18\x04 \x01(\x0b\x32%.ocf.dl.direct_lineage_objects.PathId\"M\n\x0eModelTypeFacet\x12;\n\tmodelType\x18\x01 \x01(\x0e\x32(.ocf.dl.direct_lineage_objects.ModelType\"\x98\x01\n\x10\x44\x61tasourceFacets\x12\x45\n\x0emodelTypeFacet\x18\x01 \x01(\x0b\x32-.ocf.dl.direct_lineage_objects.ModelTypeFacet\x12=\n\nmodelFacet\x18\x02 \x01(\x0b\x32).ocf.dl.direct_lineage_objects.ModelFacet\"V\n\x06PathId\x12\x13\n\x0b\x65xternal_id\x18\x01 \x01(\t\x12\x37\n\x04path\x18\x02 \x01(\x0b\x32).ocf.asset.filter_extraction_objects.Path\"5\n\nModelFacet\x12\x12\n\nexternalId\x18\x01 \x01(\t\x12\x13\n\x0b\x63olumnNames\x18\x02 \x03(\t\"\x19\n\tCodeFacet\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t\"\'\n\x10\x45xternalURLFacet\x12\x13\n\x0b\x65xternalUrl\x18\x01 \x01(\t\"\'\n\x12\x44\x61taFlowGroupFacet\x12\x11\n\tgroupName\x18\x01 \x01(\t\"\xf7\x01\n\x0e\x44\x61taflowFacets\x12;\n\tcodeFacet\x18\x01 \x01(\x0b\x32(.ocf.dl.direct_lineage_objects.CodeFacet\x12M\n\x12\x64\x61taflowGroupFacet\x18\x02 \x01(\x0b\x32\x31.ocf.dl.direct_lineage_objects.DataFlowGroupFacet\x12I\n\x10\x65xternalURLFacet\x18\x03 \x01(\x0b\x32/.ocf.dl.direct_lineage_objects.ExternalURLFacet\x12\x0e\n\x06\x64\x62Type\x18\x04 \x01(\t*@\n\tModelType\x12\t\n\x05TABLE\x10\x00\x12\x08\n\x04VIEW\x10\x01\x12\x0f\n\x0bINCREMENTAL\x10\x02\x12\r\n\tEPHEMERAL\x10\x03\x42\x31\n\x17\x61lation.sdk.ocf.dl.grpcB\x14\x44irectLineageObjectsP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dl.dl_objects_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\027alation.sdk.ocf.dl.grpcB\024DirectLineageObjectsP\001'
  _globals['_MODELTYPE']._serialized_start=1681
  _globals['_MODELTYPE']._serialized_end=1745
  _globals['_DATAFLOW']._serialized_start=143
  _globals['_DATAFLOW']._serialized_end=233
  _globals['_NATIVEOBJECT']._serialized_start=236
  _globals['_NATIVEOBJECT']._serialized_end=579
  _globals['_LINEAGEOBJECT']._serialized_start=581
  _globals['_LINEAGEOBJECT']._serialized_end=676
  _globals['_LINEAGEPATH']._serialized_start=679
  _globals['_LINEAGEPATH']._serialized_end=943
  _globals['_MODELTYPEFACET']._serialized_start=945
  _globals['_MODELTYPEFACET']._serialized_end=1022
  _globals['_DATASOURCEFACETS']._serialized_start=1025
  _globals['_DATASOURCEFACETS']._serialized_end=1177
  _globals['_PATHID']._serialized_start=1179
  _globals['_PATHID']._serialized_end=1265
  _globals['_MODELFACET']._serialized_start=1267
  _globals['_MODELFACET']._serialized_end=1320
  _globals['_CODEFACET']._serialized_start=1322
  _globals['_CODEFACET']._serialized_end=1347
  _globals['_EXTERNALURLFACET']._serialized_start=1349
  _globals['_EXTERNALURLFACET']._serialized_end=1388
  _globals['_DATAFLOWGROUPFACET']._serialized_start=1390
  _globals['_DATAFLOWGROUPFACET']._serialized_end=1429
  _globals['_DATAFLOWFACETS']._serialized_start=1432
  _globals['_DATAFLOWFACETS']._serialized_end=1679
# @@protoc_insertion_point(module_scope)
