# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rdbms/query.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from queryservice_client.protobuf.common import configuration_pb2 as common_dot_configuration__pb2
from queryservice_client.protobuf.common import auth_pb2 as common_dot_auth__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11rdbms/query.proto\x12\x0brdbms.query\x1a\x1a\x63ommon/configuration.proto\x1a\x11\x63ommon/auth.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"o\n\x13StartSessionRequest\x12\x34\n\rconfiguration\x18\x01 \x01(\x0b\x32\x1d.common.ProtobufConfiguration\x12\"\n\x0e\x61uthentication\x18\x02 \x01(\x0b\x32\n.auth.Auth\"G\n\x14StartSessionResponse\x12\x11\n\tsessionId\x18\x01 \x01(\x04\x12\x1c\n\x14supportsCancellation\x18\x02 \x01(\x08\"&\n\x11\x45ndSessionRequest\x12\x11\n\tsessionId\x18\x01 \x01(\x04\"\'\n\x12\x43\x61ncelQueryRequest\x12\x11\n\tsessionId\x18\x01 \x01(\x04\"\x15\n\x13\x43\x61ncelQueryResponse\"P\n\x0cQueryRequest\x12\x11\n\tsessionId\x18\x01 \x01(\x04\x12\r\n\x05query\x18\x02 \x01(\t\x12\r\n\x05limit\x18\x03 \x01(\x04\x12\x0f\n\x07timeout\x18\x04 \x01(\x05\"t\n\rQueryResponse\x12\x11\n\x07restart\x18\x01 \x01(\x08H\x00\x12\x13\n\tcancelled\x18\x03 \x01(\x08H\x00\x12/\n\x0bqueryResult\x18\x02 \x01(\x0b\x32\x18.rdbms.query.QueryResultH\x00\x42\n\n\x08response\">\n\x0bQueryResult\x12/\n\x07objects\x18\x01 \x03(\x0b\x32\x1e.rdbms.query.QueryResultObject\"\x9f\x02\n\x11QueryResultObject\x12\'\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\x17.rdbms.query.StreamDataH\x00\x12\x36\n\x0e\x62\x65ginResultSet\x18\x05 \x01(\x0b\x32\x1c.rdbms.query.StreamDelimiterH\x00\x12\x36\n\x0e\x65ndOfResultSet\x18\x02 \x01(\x0b\x32\x1c.rdbms.query.StreamDelimiterH\x00\x12\x35\n\rendOfMetadata\x18\x03 \x01(\x0b\x32\x1c.rdbms.query.StreamDelimiterH\x00\x12\x30\n\x08\x65ndOfRow\x18\x04 \x01(\x0b\x32\x1c.rdbms.query.StreamDelimiterH\x00\x42\x08\n\x06object\"h\n\nStreamData\x12)\n\x08metadata\x18\x01 \x01(\x0b\x32\x15.rdbms.query.MetadataH\x00\x12\'\n\x07rowData\x18\x02 \x01(\x0b\x32\x14.rdbms.query.RowDataH\x00\x42\x06\n\x04\x64\x61ta\"\\\n\x08Metadata\x12-\n\nprojection\x18\x01 \x01(\x0b\x32\x17.rdbms.query.ProjectionH\x00\x12\x15\n\x0bupdateCount\x18\x02 \x01(\x03H\x00\x42\n\n\x08metadata\"q\n\nProjection\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x12\n\nordinality\x18\x02 \x01(\x04\x12\x0c\n\x04type\x18\x03 \x01(\t\x12$\n\x05\x64type\x18\x04 \x01(\x0e\x32\x15.rdbms.query.DataType\x12\r\n\x05label\x18\x05 \x01(\t\"\x95\x03\n\x07RowData\x12!\n\x04null\x18\x01 \x01(\x0b\x32\x11.rdbms.query.NullH\x00\x12\x10\n\x06\x64ouble\x18\x02 \x01(\x01H\x00\x12\x0f\n\x05\x66loat\x18\x03 \x01(\x02H\x00\x12\x0f\n\x05int32\x18\x04 \x01(\x05H\x00\x12\x0f\n\x05int64\x18\x05 \x01(\x03H\x00\x12\x10\n\x06uint32\x18\x06 \x01(\rH\x00\x12\x10\n\x06uint64\x18\x07 \x01(\x04H\x00\x12\x0e\n\x04\x62ool\x18\x08 \x01(\x08H\x00\x12\x10\n\x06string\x18\t \x01(\tH\x00\x12\x0f\n\x05\x62ytes\x18\n \x01(\x0cH\x00\x12!\n\x04\x64\x61te\x18\x0b \x01(\x0b\x32\x11.rdbms.query.DateH\x00\x12#\n\x05\x61rray\x18\x0c \x01(\x0b\x32\x12.rdbms.query.ArrayH\x00\x12%\n\x06struct\x18\r \x01(\x0b\x32\x13.rdbms.query.StructH\x00\x12%\n\x06\x62igInt\x18\x0e \x01(\x0b\x32\x13.rdbms.query.BigIntH\x00\x12-\n\nbigDecimal\x18\x0f \x01(\x0b\x32\x17.rdbms.query.BigDecimalH\x00\x42\x06\n\x04\x64\x61ta\"/\n\x06Struct\x12%\n\x07members\x18\x01 \x03(\x0b\x32\x14.rdbms.query.RowData\",\n\x05\x41rray\x12#\n\x05\x61rray\x18\x01 \x03(\x0b\x32\x14.rdbms.query.RowData\"\x06\n\x04Null\"T\n\x04\x44\x61te\x12-\n\ttimestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1d\n\x15timezoneOffsetMinutes\x18\x02 \x01(\x03\"\x11\n\x0fStreamDelimiter\"D\n\x06\x42igInt\x12\r\n\x05value\x18\x01 \x01(\x0c\x12+\n\nendianness\x18\x02 \x01(\x0e\x32\x17.rdbms.query.Endianness\"G\n\nBigDecimal\x12\r\n\x05scale\x18\x01 \x01(\x05\x12*\n\runscaledValue\x18\x02 \x01(\x0b\x32\x13.rdbms.query.BigInt*\xb7\x01\n\x08\x44\x61taType\x12\x08\n\x04NULL\x10\x00\x12\n\n\x06\x44OUBLE\x10\x01\x12\t\n\x05\x46LOAT\x10\x02\x12\t\n\x05INT32\x10\x03\x12\t\n\x05INT64\x10\x04\x12\n\n\x06UINT32\x10\x05\x12\n\n\x06UINT64\x10\x06\x12\x08\n\x04\x42OOL\x10\x07\x12\n\n\x06STRING\x10\x08\x12\t\n\x05\x42YTES\x10\t\x12\x08\n\x04\x44\x41TE\x10\n\x12\t\n\x05\x41RRAY\x10\x0b\x12\n\n\x06STRUCT\x10\x0c\x12\n\n\x06\x42IGINT\x10\r\x12\x0e\n\nBIGDECIMAL\x10\x0e*!\n\nEndianness\x12\x07\n\x03\x42IG\x10\x00\x12\n\n\x06LITTLE\x10\x01\x42\x45\n\x1c\x61lation.sdk.rdbms.grpc.queryB\x16RdbmsQueryServiceProtoP\x01Z\x0brdbms/queryb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'rdbms.query_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\034alation.sdk.rdbms.grpc.queryB\026RdbmsQueryServiceProtoP\001Z\013rdbms/query'
  _globals['_DATATYPE']._serialized_start=2033
  _globals['_DATATYPE']._serialized_end=2216
  _globals['_ENDIANNESS']._serialized_start=2218
  _globals['_ENDIANNESS']._serialized_end=2251
  _globals['_STARTSESSIONREQUEST']._serialized_start=114
  _globals['_STARTSESSIONREQUEST']._serialized_end=225
  _globals['_STARTSESSIONRESPONSE']._serialized_start=227
  _globals['_STARTSESSIONRESPONSE']._serialized_end=298
  _globals['_ENDSESSIONREQUEST']._serialized_start=300
  _globals['_ENDSESSIONREQUEST']._serialized_end=338
  _globals['_CANCELQUERYREQUEST']._serialized_start=340
  _globals['_CANCELQUERYREQUEST']._serialized_end=379
  _globals['_CANCELQUERYRESPONSE']._serialized_start=381
  _globals['_CANCELQUERYRESPONSE']._serialized_end=402
  _globals['_QUERYREQUEST']._serialized_start=404
  _globals['_QUERYREQUEST']._serialized_end=484
  _globals['_QUERYRESPONSE']._serialized_start=486
  _globals['_QUERYRESPONSE']._serialized_end=602
  _globals['_QUERYRESULT']._serialized_start=604
  _globals['_QUERYRESULT']._serialized_end=666
  _globals['_QUERYRESULTOBJECT']._serialized_start=669
  _globals['_QUERYRESULTOBJECT']._serialized_end=956
  _globals['_STREAMDATA']._serialized_start=958
  _globals['_STREAMDATA']._serialized_end=1062
  _globals['_METADATA']._serialized_start=1064
  _globals['_METADATA']._serialized_end=1156
  _globals['_PROJECTION']._serialized_start=1158
  _globals['_PROJECTION']._serialized_end=1271
  _globals['_ROWDATA']._serialized_start=1274
  _globals['_ROWDATA']._serialized_end=1679
  _globals['_STRUCT']._serialized_start=1681
  _globals['_STRUCT']._serialized_end=1728
  _globals['_ARRAY']._serialized_start=1730
  _globals['_ARRAY']._serialized_end=1774
  _globals['_NULL']._serialized_start=1776
  _globals['_NULL']._serialized_end=1782
  _globals['_DATE']._serialized_start=1784
  _globals['_DATE']._serialized_end=1868
  _globals['_STREAMDELIMITER']._serialized_start=1870
  _globals['_STREAMDELIMITER']._serialized_end=1887
  _globals['_BIGINT']._serialized_start=1889
  _globals['_BIGINT']._serialized_end=1957
  _globals['_BIGDECIMAL']._serialized_start=1959
  _globals['_BIGDECIMAL']._serialized_end=2030
# @@protoc_insertion_point(module_scope)
