# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: common/verify.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from queryservice_client.protobuf.common import configuration_pb2 as common_dot_configuration__pb2
from queryservice_client.protobuf.common import auth_pb2 as common_dot_auth__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13\x63ommon/verify.proto\x12\x06verify\x1a\x1a\x63ommon/configuration.proto\x1a\x11\x63ommon/auth.proto\"j\n\x07Request\x12\x34\n\rconfiguration\x18\x01 \x01(\x0b\x32\x1d.common.ProtobufConfiguration\x12\x18\n\x04\x61uth\x18\x02 \x01(\x0b\x32\n.auth.Auth\x12\x0f\n\x07jdbcUri\x18\x03 \x01(\tB9\n\x1e\x61lation.sdk.grpc.common.verifyB\x06VerifyP\x01Z\rcommon/verifyb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'common.verify_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\036alation.sdk.grpc.common.verifyB\006VerifyP\001Z\rcommon/verify'
  _globals['_REQUEST']._serialized_start=78
  _globals['_REQUEST']._serialized_end=184
# @@protoc_insertion_point(module_scope)
