# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bi/certify.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from queryservice_client.protobuf.common import configuration_pb2 as common_dot_configuration__pb2
from bi import mde_objects_pb2 as bi_dot_mde__objects__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10\x62i/certify.proto\x12\nbi.certify\x1a\x1a\x63ommon/configuration.proto\x1a\x14\x62i/mde_objects.proto\"\xa3\x01\n\x1dPropagateCertificationRequest\x12\x34\n\rconfiguration\x18\x01 \x01(\x0b\x32\x1d.common.ProtobufConfiguration\x12-\n\x08\x62iObject\x18\x02 \x01(\x0b\x32\x1b.bi.mde_objects.GBMBIObject\x12\x0c\n\x04note\x18\x03 \x01(\t\x12\x0f\n\x07\x63\x65rtify\x18\x04 \x01(\x08\x42\x37\n\x1b\x61lation.sdk.bi.grpc.certifyB\x16PropagateCertificationP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bi.certify_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033alation.sdk.bi.grpc.certifyB\026PropagateCertificationP\001'
  _globals['_PROPAGATECERTIFICATIONREQUEST']._serialized_start=83
  _globals['_PROPAGATECERTIFICATIONREQUEST']._serialized_end=246
# @@protoc_insertion_point(module_scope)
