# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bi/mde_objects.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14\x62i/mde_objects.proto\x12\x0e\x62i.mde_objects\"\x8e\x02\n\x0bGBMBIObject\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x14\n\x0c\x62iObjectType\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x11\n\tcreatedAt\x18\x05 \x01(\t\x12\x13\n\x0blastUpdated\x18\x06 \x01(\t\x12\x12\n\nsource_url\x18\x07 \x01(\t\x12G\n\x0e\x62iCompositeKey\x18\x08 \x03(\x0b\x32/.bi.mde_objects.GBMBIObject.BiCompositeKeyEntry\x1a\x35\n\x13\x42iCompositeKeyEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"L\n\tGBMBIUser\x12-\n\x08\x62iObject\x18\x01 \x01(\x0b\x32\x1b.bi.mde_objects.GBMBIObject\x12\x10\n\x08username\x18\x02 \x01(\t\"\xa9\x01\n\x0bGBMBIFolder\x12-\n\x08\x62iObject\x18\x01 \x01(\x0b\x32\x1b.bi.mde_objects.GBMBIObject\x12\r\n\x05owner\x18\x02 \x01(\t\x12\x12\n\nnumReports\x18\x03 \x01(\x05\x12\x19\n\x11numReportAccesses\x18\x04 \x01(\x05\x12\x16\n\x0eparentFolderId\x18\x05 \x01(\t\x12\x15\n\risExtractable\x18\x06 \x01(\x08\"\xfb\x01\n\x0bGBMBIReport\x12-\n\x08\x62iObject\x18\x01 \x01(\x0b\x32\x1b.bi.mde_objects.GBMBIObject\x12\r\n\x05owner\x18\x02 \x01(\t\x12\x13\n\x0bnumAccesses\x18\x03 \x01(\x05\x12\x16\n\x0eparentFolderId\x18\x04 \x01(\t\x12\x17\n\x0fparentReportIds\x18\x05 \x03(\t\x12\x15\n\rdatasourceIds\x18\x06 \x03(\t\x12.\n\x04type\x18\x07 \x01(\x0e\x32 .bi.mde_objects.GBMBIReport.Type\"!\n\x04Type\x12\n\n\x06SIMPLE\x10\x00\x12\r\n\tDASHBOARD\x10\x01\"\x9b\x01\n\x0fGBMBIDatasource\x12-\n\x08\x62iObject\x18\x01 \x01(\x0b\x32\x1b.bi.mde_objects.GBMBIObject\x12\r\n\x05owner\x18\x02 \x01(\t\x12\x16\n\x0eparentFolderId\x18\x03 \x01(\t\x12\x15\n\rconnectionIds\x18\x04 \x03(\t\x12\x1b\n\x13linkedDatasourceIds\x18\x05 \x03(\t\"\xe2\x02\n\x0fGBMBIConnection\x12-\n\x08\x62iObject\x18\x01 \x01(\x0b\x32\x1b.bi.mde_objects.GBMBIObject\x12\x16\n\x0eparentFolderId\x18\x02 \x01(\t\x12<\n\x0e\x63onnectionType\x18\x03 \x01(\x0e\x32$.bi.mde_objects.GBMBIConnection.Type\x12\x1d\n\x15\x64isplayConnectionType\x18\x04 \x01(\t\x12\x14\n\x0c\x64\x61tabaseType\x18\x05 \x01(\t\x12\x0c\n\x04host\x18\x06 \x01(\t\x12\x0c\n\x04port\x18\x07 \x01(\t\x12\x10\n\x08\x64\x62Schema\x18\x08 \x01(\t\x12\x0f\n\x07\x64\x62Table\x18\t \x01(\t\x12\x0b\n\x03sql\x18\n \x01(\t\x12\x11\n\tdataFiles\x18\x0b \x03(\t\"6\n\x04Type\x12\t\n\x05\x46ILES\x10\x00\x12\t\n\x05TABLE\x10\x01\x12\r\n\tSQL_QUERY\x10\x02\x12\t\n\x05OTHER\x10\x03\"\x84\x01\n\x0fGBMBIColumnBase\x12-\n\x08\x62iObject\x18\x01 \x01(\x0b\x32\x1b.bi.mde_objects.GBMBIObject\x12\x10\n\x08\x64\x61taType\x18\x02 \x01(\t\x12\x0c\n\x04role\x18\x03 \x01(\t\x12\x12\n\nexpression\x18\x04 \x01(\t\x12\x0e\n\x06values\x18\x05 \x03(\t\"\x98\x01\n\x11GBMBIReportColumn\x12\x35\n\x0c\x62iColumnBase\x18\x01 \x01(\x0b\x32\x1f.bi.mde_objects.GBMBIColumnBase\x12\x10\n\x08reportId\x18\x02 \x01(\t\x12\x1b\n\x13\x64\x61tasourceColumnIds\x18\x03 \x03(\t\x12\x1d\n\x15parentReportColumnIds\x18\x04 \x03(\t\"\xaa\x01\n\x15GBMBIDatasourceColumn\x12\x35\n\x0c\x62iColumnBase\x18\x01 \x01(\x0b\x32\x1f.bi.mde_objects.GBMBIColumnBase\x12\x14\n\x0c\x64\x61tasourceId\x18\x02 \x01(\t\x12!\n\x19parentDatasourceColumnIds\x18\x03 \x03(\t\x12!\n\x19parentConnectionColumnIds\x18\x04 \x03(\t\"d\n\x15GBMBIConnectionColumn\x12\x35\n\x0c\x62iColumnBase\x18\x01 \x01(\x0b\x32\x1f.bi.mde_objects.GBMBIColumnBase\x12\x14\n\x0c\x63onnectionId\x18\x02 \x01(\t\"d\n\x0fGBMBIPermission\x12\x16\n\x0euserExternalId\x18\x01 \x01(\t\x12\x13\n\x0bobjectOType\x18\x02 \x01(\t\x12\x18\n\x10objectExternalId\x18\x03 \x01(\t\x12\n\n\x02id\x18\x04 \x01(\t\"Y\n\nGBMBIImage\x12\x11\n\timageName\x18\x01 \x01(\t\x12\x11\n\timageData\x18\x02 \x01(\x0c\x12\x14\n\x0c\x65rrorMessage\x18\x03 \x01(\t\x12\x0f\n\x07hasMore\x18\x04 \x01(\x08\"\x1f\n\x0b\x41lationUser\x12\x10\n\x08username\x18\x01 \x01(\tB,\n\x17\x61lation.sdk.bi.grpc.mdeB\x0fMetadataObjectsP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bi.mde_objects_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\027alation.sdk.bi.grpc.mdeB\017MetadataObjectsP\001'
  _globals['_GBMBIOBJECT_BICOMPOSITEKEYENTRY']._options = None
  _globals['_GBMBIOBJECT_BICOMPOSITEKEYENTRY']._serialized_options = b'8\001'
  _globals['_GBMBIOBJECT']._serialized_start=41
  _globals['_GBMBIOBJECT']._serialized_end=311
  _globals['_GBMBIOBJECT_BICOMPOSITEKEYENTRY']._serialized_start=258
  _globals['_GBMBIOBJECT_BICOMPOSITEKEYENTRY']._serialized_end=311
  _globals['_GBMBIUSER']._serialized_start=313
  _globals['_GBMBIUSER']._serialized_end=389
  _globals['_GBMBIFOLDER']._serialized_start=392
  _globals['_GBMBIFOLDER']._serialized_end=561
  _globals['_GBMBIREPORT']._serialized_start=564
  _globals['_GBMBIREPORT']._serialized_end=815
  _globals['_GBMBIREPORT_TYPE']._serialized_start=782
  _globals['_GBMBIREPORT_TYPE']._serialized_end=815
  _globals['_GBMBIDATASOURCE']._serialized_start=818
  _globals['_GBMBIDATASOURCE']._serialized_end=973
  _globals['_GBMBICONNECTION']._serialized_start=976
  _globals['_GBMBICONNECTION']._serialized_end=1330
  _globals['_GBMBICONNECTION_TYPE']._serialized_start=1276
  _globals['_GBMBICONNECTION_TYPE']._serialized_end=1330
  _globals['_GBMBICOLUMNBASE']._serialized_start=1333
  _globals['_GBMBICOLUMNBASE']._serialized_end=1465
  _globals['_GBMBIREPORTCOLUMN']._serialized_start=1468
  _globals['_GBMBIREPORTCOLUMN']._serialized_end=1620
  _globals['_GBMBIDATASOURCECOLUMN']._serialized_start=1623
  _globals['_GBMBIDATASOURCECOLUMN']._serialized_end=1793
  _globals['_GBMBICONNECTIONCOLUMN']._serialized_start=1795
  _globals['_GBMBICONNECTIONCOLUMN']._serialized_end=1895
  _globals['_GBMBIPERMISSION']._serialized_start=1897
  _globals['_GBMBIPERMISSION']._serialized_end=1997
  _globals['_GBMBIIMAGE']._serialized_start=1999
  _globals['_GBMBIIMAGE']._serialized_end=2088
  _globals['_ALATIONUSER']._serialized_start=2090
  _globals['_ALATIONUSER']._serialized_end=2121
# @@protoc_insertion_point(module_scope)
