# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: asset/configuration_verifycation.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from queryservice_client.protobuf.common import verify_pb2 as common_dot_verify__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&asset/configuration_verifycation.proto\x12$ocf.asset.configuration_verification\x1a\x13\x63ommon/verify.proto\x1a\x1bgoogle/protobuf/empty.proto2c\n\x19\x43onfigurationVerification\x12\x46\n\x19\x43onfigurationVerification\x12\x0f.verify.Request\x1a\x16.google.protobuf.Empty\"\x00\x42W\n1alation.sdk.asset.grpc.configuration_verificationP\x01Z asset/configuration_verificationb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'asset.configuration_verifycation_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n1alation.sdk.asset.grpc.configuration_verificationP\001Z asset/configuration_verification'
  _globals['_CONFIGURATIONVERIFICATION']._serialized_start=130
  _globals['_CONFIGURATIONVERIFICATION']._serialized_end=229
# @@protoc_insertion_point(module_scope)
