# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: policy/policy_rdbms.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from queryservice_client.protobuf.common import configuration_pb2 as common_dot_configuration__pb2
from policy import policy_objects_pb2 as policy_dot_policy__objects__pb2
from queryservice_client.protobuf.rdbms import mde_pb2 as rdbms_dot_mde__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19policy/policy_rdbms.proto\x12\x10ocf.policy.rdbms\x1a\x1a\x63ommon/configuration.proto\x1a\x1bpolicy/policy_objects.proto\x1a\x0frdbms/mde.proto\"\x9f\x01\n\x17PolicyExtractionRequest\x12\x34\n\rconfiguration\x18\x01 \x01(\x0b\x32\x1d.common.ProtobufConfiguration\x12\x33\n\x06\x66ilter\x18\x02 \x03(\x0b\x32#.rdbms.mde.FilterExtractionResponse\x12\x19\n\x11is_include_filter\x18\x03 \x01(\x08\"\xe3\x01\n\x18PolicyExtractionResponse\x12\x33\n\x06policy\x18\x01 \x01(\x0b\x32!.ocf.policy.policy_objects.PolicyH\x00\x12\x39\n\ttableLink\x18\x02 \x01(\x0b\x32$.ocf.policy.policy_objects.TableLinkH\x00\x12;\n\ncolumnLink\x18\x03 \x01(\x0b\x32%.ocf.policy.policy_objects.ColumnLinkH\x00\x42\x1a\n\x18PolicyExtractionResponse2\x7f\n\x0eRdbmsPolicyMDE\x12m\n\x10PolicyExtraction\x12).ocf.policy.rdbms.PolicyExtractionRequest\x1a*.ocf.policy.rdbms.PolicyExtractionResponse\"\x00\x30\x01\x42\x33\n\x1b\x61lation.sdk.ocf.policy.grpcB\x12MetadataExtractionP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'policy.policy_rdbms_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033alation.sdk.ocf.policy.grpcB\022MetadataExtractionP\001'
  _globals['_POLICYEXTRACTIONREQUEST']._serialized_start=122
  _globals['_POLICYEXTRACTIONREQUEST']._serialized_end=281
  _globals['_POLICYEXTRACTIONRESPONSE']._serialized_start=284
  _globals['_POLICYEXTRACTIONRESPONSE']._serialized_end=511
  _globals['_RDBMSPOLICYMDE']._serialized_start=513
  _globals['_RDBMSPOLICYMDE']._serialized_end=640
# @@protoc_insertion_point(module_scope)
