# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cf/cf_rdbms.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cf import cf_objects_pb2 as cf_dot_cf__objects__pb2
from queryservice_client.protobuf.rdbms import mde_pb2 as rdbms_dot_mde__pb2
from queryservice_client.protobuf.common import configuration_pb2 as common_dot_configuration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11\x63\x66/cf_rdbms.proto\x12\x0cocf.cf.rdbms\x1a\x13\x63\x66/cf_objects.proto\x1a\x0frdbms/mde.proto\x1a\x1a\x63ommon/configuration.proto\"\xa4\x01\n\x1c\x43ustomFieldExtractionRequest\x12\x34\n\rconfiguration\x18\x01 \x01(\x0b\x32\x1d.common.ProtobufConfiguration\x12\x33\n\x06\x66ilter\x18\x02 \x03(\x0b\x32#.rdbms.mde.FilterExtractionResponse\x12\x19\n\x11is_include_filter\x18\x03 \x01(\x08\"\xa5\x01\n\x1d\x43ustomFieldExtractionResponse\x12/\n\x05\x66ield\x18\x01 \x01(\x0b\x32\x1e.ocf.cf.cf_objects.CustomFieldH\x00\x12\x32\n\x04link\x18\x02 \x01(\x0b\x32\".ocf.cf.cf_objects.CustomFieldLinkH\x00\x42\x1f\n\x1d\x43ustomFieldExtractionResponse2\x8b\x01\n\x13RdbmsCustomFieldMDE\x12t\n\x15\x43ustomFieldExtraction\x12*.ocf.cf.rdbms.CustomFieldExtractionRequest\x1a+.ocf.cf.rdbms.CustomFieldExtractionResponse\"\x00\x30\x01\x42/\n\x17\x61lation.sdk.ocf.cf.grpcB\x12MetadataExtractionP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cf.cf_rdbms_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\027alation.sdk.ocf.cf.grpcB\022MetadataExtractionP\001'
  _globals['_CUSTOMFIELDEXTRACTIONREQUEST']._serialized_start=102
  _globals['_CUSTOMFIELDEXTRACTIONREQUEST']._serialized_end=266
  _globals['_CUSTOMFIELDEXTRACTIONRESPONSE']._serialized_start=269
  _globals['_CUSTOMFIELDEXTRACTIONRESPONSE']._serialized_end=434
  _globals['_RDBMSCUSTOMFIELDMDE']._serialized_start=437
  _globals['_RDBMSCUSTOMFIELDMDE']._serialized_end=576
# @@protoc_insertion_point(module_scope)
