# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: asset/mde.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from queryservice_client.protobuf.common import configuration_pb2 as common_dot_configuration__pb2
from queryservice_client.protobuf.common import job_error_pb2 as common_dot_job__error__pb2
from asset import mde_objects_pb2 as asset_dot_mde__objects__pb2
from asset import filter_extraction_pb2 as asset_dot_filter__extraction__pb2
from queryservice_client.protobuf.common import extraction_objects_pb2 as common_dot_extraction__objects__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0f\x61sset/mde.proto\x12\rocf.asset.mde\x1a\x1a\x63ommon/configuration.proto\x1a\x16\x63ommon/job_error.proto\x1a\x17\x61sset/mde_objects.proto\x1a\x1d\x61sset/filter_extraction.proto\x1a\x1f\x63ommon/extraction_objects.proto\"\xb3\x01\n\x19MetadataExtractionRequest\x12\x34\n\rconfiguration\x18\x01 \x01(\x0b\x32\x1d.common.ProtobufConfiguration\x12\x45\n\x06\x66ilter\x18\x02 \x03(\x0b\x32\x35.ocf.asset.filter_extraction.FilterExtractionResponse\x12\x19\n\x11isInclusionFilter\x18\x03 \x01(\x08\"\x81\x02\n\x1aMetadataExtractionResponse\x12-\n\x05\x61sset\x18\x01 \x01(\x0b\x32\x1c.ocf.asset.mde_objects.AssetH\x00\x12!\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x10.job_error.ErrorH\x00\x12\x44\n\x12\x65xtractionProgress\x18\x03 \x01(\x0b\x32&.extraction_objects.ExtractionProgressH\x00\x12?\n\x0e\x64qRuleAndValue\x18\x04 \x01(\x0b\x32%.ocf.asset.mde_objects.DQRuleAndValueH\x00\x42\n\n\x08response2\x83\x01\n\x12MetadataExtraction\x12m\n\x12MetadataExtraction\x12(.ocf.asset.mde.MetadataExtractionRequest\x1a).ocf.asset.mde.MetadataExtractionResponse\"\x00\x30\x01\x42)\n\x1a\x61lation.sdk.asset.grpc.mdeP\x01Z\tasset/mdeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'asset.mde_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\032alation.sdk.asset.grpc.mdeP\001Z\tasset/mde'
  _globals['_METADATAEXTRACTIONREQUEST']._serialized_start=176
  _globals['_METADATAEXTRACTIONREQUEST']._serialized_end=355
  _globals['_METADATAEXTRACTIONRESPONSE']._serialized_start=358
  _globals['_METADATAEXTRACTIONRESPONSE']._serialized_end=615
  _globals['_METADATAEXTRACTION']._serialized_start=618
  _globals['_METADATAEXTRACTION']._serialized_end=749
# @@protoc_insertion_point(module_scope)
