# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: common/checks.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from queryservice_client.protobuf.common import configuration_pb2 as common_dot_configuration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13\x63ommon/checks.proto\x12\x06\x63hecks\x1a\x1a\x63ommon/configuration.proto\"|\n\x0c\x43heckRequest\x12\x34\n\rconfiguration\x18\x01 \x01(\x0b\x32\x1d.common.ProtobufConfiguration\x12\x12\n\ncheck_name\x18\x02 \x01(\t\x12\"\n\tcheck_ids\x18\x03 \x03(\x0b\x32\x0f.checks.CheckID\"\x15\n\x07\x43heckID\x12\n\n\x02id\x18\x01 \x01(\t\"\x88\x01\n\x0b\x43heckResult\x12\n\n\x02id\x18\x01 \x01(\t\x12#\n\x06result\x18\x02 \x01(\x0e\x32\x13.checks.CheckStatus\x12!\n\x05\x65rror\x18\x03 \x01(\x0b\x32\x12.checks.CheckError\x12%\n\x07message\x18\x04 \x01(\x0b\x32\x14.checks.CheckMessage\"D\n\nCheckError\x12\x12\n\nerror_code\x18\x01 \x01(\t\x12\x12\n\nerror_text\x18\x02 \x01(\t\x12\x0e\n\x06\x61\x63tion\x18\x03 \x01(\t\",\n\x0c\x43heckMessage\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x0e\n\x06\x61\x63tion\x18\x02 \x01(\t*A\n\x0b\x43heckStatus\x12\x0b\n\x07SUCCESS\x10\x00\x12\x0b\n\x07\x46\x41ILURE\x10\x01\x12\x0b\n\x07SKIPPED\x10\x02\x12\x0b\n\x07WARNING\x10\x03\x42\x39\n\x1e\x61lation.sdk.grpc.common.checksB\x06\x43hecksP\x01Z\rcommon/checksb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'common.checks_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\036alation.sdk.grpc.common.checksB\006ChecksP\001Z\rcommon/checks'
  _globals['_CHECKSTATUS']._serialized_start=463
  _globals['_CHECKSTATUS']._serialized_end=528
  _globals['_CHECKREQUEST']._serialized_start=59
  _globals['_CHECKREQUEST']._serialized_end=183
  _globals['_CHECKID']._serialized_start=185
  _globals['_CHECKID']._serialized_end=206
  _globals['_CHECKRESULT']._serialized_start=209
  _globals['_CHECKRESULT']._serialized_end=345
  _globals['_CHECKERROR']._serialized_start=347
  _globals['_CHECKERROR']._serialized_end=415
  _globals['_CHECKMESSAGE']._serialized_start=417
  _globals['_CHECKMESSAGE']._serialized_end=461
# @@protoc_insertion_point(module_scope)
