# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rdbms/mde_objects.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17rdbms/mde_objects.proto\x12\x11rdbms.mde_objects\",\n\x04Name\x12\x10\n\x08original\x18\x01 \x01(\t\x12\x12\n\nnormalized\x18\x02 \x01(\t\":\n\x11\x44\x61tabaseCatalogId\x12%\n\x04name\x18\x01 \x01(\x0b\x32\x17.rdbms.mde_objects.Name\"c\n\x08SchemaId\x12\x30\n\x0f\x64\x61tabaseCatalog\x18\x01 \x01(\x0b\x32\x17.rdbms.mde_objects.Name\x12%\n\x04name\x18\x02 \x01(\x0b\x32\x17.rdbms.mde_objects.Name\"\x8b\x01\n\x07TableId\x12\x30\n\x0f\x64\x61tabaseCatalog\x18\x01 \x01(\x0b\x32\x17.rdbms.mde_objects.Name\x12\'\n\x06schema\x18\x02 \x01(\x0b\x32\x17.rdbms.mde_objects.Name\x12%\n\x04name\x18\x03 \x01(\x0b\x32\x17.rdbms.mde_objects.Name\"\xb4\x01\n\x08\x43olumnId\x12\x30\n\x0f\x64\x61tabaseCatalog\x18\x01 \x01(\x0b\x32\x17.rdbms.mde_objects.Name\x12\'\n\x06schema\x18\x02 \x01(\x0b\x32\x17.rdbms.mde_objects.Name\x12&\n\x05table\x18\x03 \x01(\x0b\x32\x17.rdbms.mde_objects.Name\x12%\n\x04name\x18\x04 \x01(\x0b\x32\x17.rdbms.mde_objects.Name\"\x8e\x01\n\nFunctionId\x12\x30\n\x0f\x64\x61tabaseCatalog\x18\x01 \x01(\x0b\x32\x17.rdbms.mde_objects.Name\x12\'\n\x06schema\x18\x02 \x01(\x0b\x32\x17.rdbms.mde_objects.Name\x12%\n\x04name\x18\x03 \x01(\x0b\x32\x17.rdbms.mde_objects.Name\"Z\n\x0f\x44\x61tabaseCatalog\x12\x30\n\x02id\x18\x01 \x01(\x0b\x32$.rdbms.mde_objects.DatabaseCatalogId\x12\x15\n\rsourceComment\x18\x02 \x01(\t\"[\n\x06Schema\x12\'\n\x02id\x18\x01 \x01(\x0b\x32\x1b.rdbms.mde_objects.SchemaId\x12\x15\n\rsourceComment\x18\x02 \x01(\t\x12\x11\n\tisDeleted\x18\x03 \x01(\x08\"\x8e\x01\n\tTableType\x12\x0c\n\x04name\x18\x01 \x01(\t\x12?\n\nnormalized\x18\x03 \x01(\x0e\x32+.rdbms.mde_objects.TableType.NormalizedType\"2\n\x0eNormalizedType\x12\t\n\x05TABLE\x10\x00\x12\x08\n\x04VIEW\x10\x01\x12\x0b\n\x07SYNONYM\x10\x03\"M\n\tPartition\x12\x12\n\ndefinition\x18\x01 \x01(\t\x12,\n\x07\x63olumns\x18\x02 \x03(\x0b\x32\x1b.rdbms.mde_objects.ColumnId\"\"\n\x0e\x46ileSystemPath\x12\x10\n\x08segments\x18\x01 \x03(\t\"s\n\x0c\x44\x61taLocation\x12\x10\n\x08original\x18\x01 \x01(\t\x12\x0e\n\x06scheme\x18\x02 \x01(\t\x12\x10\n\x08hostport\x18\x03 \x01(\t\x12/\n\x04path\x18\x04 \x01(\x0b\x32!.rdbms.mde_objects.FileSystemPath\"\xc7\x03\n\x05Table\x12&\n\x02id\x18\x01 \x01(\x0b\x32\x1a.rdbms.mde_objects.TableId\x12\x15\n\rsourceComment\x18\x02 \x01(\t\x12*\n\x04type\x18\x03 \x01(\x0b\x32\x1c.rdbms.mde_objects.TableType\x12\x0b\n\x03\x64\x64l\x18\x04 \x01(\t\x12/\n\tpartition\x18\x05 \x01(\x0b\x32\x1c.rdbms.mde_objects.Partition\x12-\n\tbaseTable\x18\x06 \x01(\x0b\x32\x1a.rdbms.mde_objects.TableId\x12\r\n\x05owner\x18\x07 \x01(\t\x12\x35\n\x0c\x64\x61taLocation\x18\x08 \x01(\x0b\x32\x1f.rdbms.mde_objects.DataLocation\x12P\n\x14\x61\x64\x64itionalProperties\x18\t \x03(\x0b\x32\x32.rdbms.mde_objects.Table.AdditionalPropertiesEntry\x12\x11\n\tisDeleted\x18\n \x01(\x08\x1a;\n\x19\x41\x64\x64itionalPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xda\x01\n\nColumnType\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x12\n\ndefinition\x18\x02 \x01(\t\x12@\n\nnormalized\x18\x03 \x01(\x0e\x32,.rdbms.mde_objects.ColumnType.NormalizedType\"h\n\x0eNormalizedType\x12\t\n\x05OTHER\x10\x00\x12\x08\n\x04\x42OOL\x10\x01\x12\x08\n\x04\x44\x41TE\x10\x02\x12\x07\n\x03INT\x10\x03\x12\t\n\x05\x46LOAT\x10\x04\x12\n\n\x06STRING\x10\x05\x12\x08\n\x04TIME\x10\x06\x12\r\n\tTIMESTAMP\x10\x07\"\x8e\x01\n\x11TableIndexingInfo\x12\x14\n\x0cisPrimaryKey\x18\x01 \x01(\x08\x12\x14\n\x0cisForeignKey\x18\x02 \x01(\x08\x12\x37\n\x12referencedColumnId\x18\x03 \x01(\x0b\x32\x1b.rdbms.mde_objects.ColumnId\x12\x14\n\x0cisOtherIndex\x18\x04 \x01(\x08\"\xe7\x01\n\x06\x43olumn\x12\'\n\x02id\x18\x01 \x01(\x0b\x32\x1b.rdbms.mde_objects.ColumnId\x12\x15\n\rsourceComment\x18\x02 \x01(\t\x12+\n\x04type\x18\x03 \x01(\x0b\x32\x1d.rdbms.mde_objects.ColumnType\x12\x10\n\x08position\x18\x04 \x01(\x05\x12\x12\n\nisNullable\x18\x05 \x01(\x08\x12\x37\n\tindexInfo\x18\x06 \x01(\x0b\x32$.rdbms.mde_objects.TableIndexingInfo\x12\x11\n\tisDeleted\x18\x07 \x01(\x08\"s\n\x08\x46unction\x12)\n\x02id\x18\x01 \x01(\x0b\x32\x1d.rdbms.mde_objects.FunctionId\x12\x15\n\rsourceComment\x18\x02 \x01(\t\x12\x12\n\nsignatures\x18\x03 \x03(\t\x12\x11\n\tisDeleted\x18\x04 \x01(\x08\"<\n\x0bSchemaApiId\x12-\n\x08schemaId\x18\x01 \x01(\x0b\x32\x1b.rdbms.mde_objects.SchemaId\"j\n\nTableApiId\x12+\n\x07tableId\x18\x01 \x01(\x0b\x32\x1a.rdbms.mde_objects.TableId\x12/\n\ttableType\x18\x02 \x01(\x0b\x32\x1c.rdbms.mde_objects.TableType\"m\n\x0b\x43olumnApiId\x12-\n\x08\x63olumnId\x18\x01 \x01(\x0b\x32\x1b.rdbms.mde_objects.ColumnId\x12/\n\ttableType\x18\x02 \x01(\x0b\x32\x1c.rdbms.mde_objects.TableType*N\n\x05Otype\x12\x14\n\x10\x44\x41TABASE_CATALOG\x10\x00\x12\n\n\x06SCHEMA\x10\x01\x12\t\n\x05TABLE\x10\x02\x12\n\n\x06\x43OLUMN\x10\x03\x12\x0c\n\x08\x46UNCTION\x10\x04\x42\x42\n\x1a\x61lation.sdk.rdbms.grpc.mdeB\x0fMetadataObjectsP\x01Z\x11rdbms/mde_objectsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'rdbms.mde_objects_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\032alation.sdk.rdbms.grpc.mdeB\017MetadataObjectsP\001Z\021rdbms/mde_objects'
  _globals['_TABLE_ADDITIONALPROPERTIESENTRY']._options = None
  _globals['_TABLE_ADDITIONALPROPERTIESENTRY']._serialized_options = b'8\001'
  _globals['_OTYPE']._serialized_start=2741
  _globals['_OTYPE']._serialized_end=2819
  _globals['_NAME']._serialized_start=46
  _globals['_NAME']._serialized_end=90
  _globals['_DATABASECATALOGID']._serialized_start=92
  _globals['_DATABASECATALOGID']._serialized_end=150
  _globals['_SCHEMAID']._serialized_start=152
  _globals['_SCHEMAID']._serialized_end=251
  _globals['_TABLEID']._serialized_start=254
  _globals['_TABLEID']._serialized_end=393
  _globals['_COLUMNID']._serialized_start=396
  _globals['_COLUMNID']._serialized_end=576
  _globals['_FUNCTIONID']._serialized_start=579
  _globals['_FUNCTIONID']._serialized_end=721
  _globals['_DATABASECATALOG']._serialized_start=723
  _globals['_DATABASECATALOG']._serialized_end=813
  _globals['_SCHEMA']._serialized_start=815
  _globals['_SCHEMA']._serialized_end=906
  _globals['_TABLETYPE']._serialized_start=909
  _globals['_TABLETYPE']._serialized_end=1051
  _globals['_TABLETYPE_NORMALIZEDTYPE']._serialized_start=1001
  _globals['_TABLETYPE_NORMALIZEDTYPE']._serialized_end=1051
  _globals['_PARTITION']._serialized_start=1053
  _globals['_PARTITION']._serialized_end=1130
  _globals['_FILESYSTEMPATH']._serialized_start=1132
  _globals['_FILESYSTEMPATH']._serialized_end=1166
  _globals['_DATALOCATION']._serialized_start=1168
  _globals['_DATALOCATION']._serialized_end=1283
  _globals['_TABLE']._serialized_start=1286
  _globals['_TABLE']._serialized_end=1741
  _globals['_TABLE_ADDITIONALPROPERTIESENTRY']._serialized_start=1682
  _globals['_TABLE_ADDITIONALPROPERTIESENTRY']._serialized_end=1741
  _globals['_COLUMNTYPE']._serialized_start=1744
  _globals['_COLUMNTYPE']._serialized_end=1962
  _globals['_COLUMNTYPE_NORMALIZEDTYPE']._serialized_start=1858
  _globals['_COLUMNTYPE_NORMALIZEDTYPE']._serialized_end=1962
  _globals['_TABLEINDEXINGINFO']._serialized_start=1965
  _globals['_TABLEINDEXINGINFO']._serialized_end=2107
  _globals['_COLUMN']._serialized_start=2110
  _globals['_COLUMN']._serialized_end=2341
  _globals['_FUNCTION']._serialized_start=2343
  _globals['_FUNCTION']._serialized_end=2458
  _globals['_SCHEMAAPIID']._serialized_start=2460
  _globals['_SCHEMAAPIID']._serialized_end=2520
  _globals['_TABLEAPIID']._serialized_start=2522
  _globals['_TABLEAPIID']._serialized_end=2628
  _globals['_COLUMNAPIID']._serialized_start=2630
  _globals['_COLUMNAPIID']._serialized_end=2739
# @@protoc_insertion_point(module_scope)
