# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rdbms/qle.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from queryservice_client.protobuf.common import configuration_pb2 as common_dot_configuration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0frdbms/qle.proto\x12\trdbms.qle\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1a\x63ommon/configuration.proto\"v\n\x07Request\x12\x34\n\rconfiguration\x18\x01 \x01(\x0b\x32\x1d.common.ProtobufConfiguration\x12\x35\n\x10runConfiguration\x18\x02 \x01(\x0b\x32\x1b.rdbms.qle.RunConfiguration\"}\n\x10RunConfiguration\x12\r\n\x05limit\x18\x01 \x01(\x04\x12-\n\tstartTime\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12+\n\x07\x65ndTime\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\x82\x01\n\x08Response\x12.\n\tstatement\x18\x01 \x01(\x0b\x32\x19.rdbms.qle.QueryStatementH\x00\x12(\n\x06result\x18\x02 \x01(\x0b\x32\x16.rdbms.qle.FinalResultH\x00\x12\x10\n\x08isResult\x18\x03 \x01(\x08\x42\n\n\x08response\"\xa0\x01\n\x0b\x46inalResult\x12\x16\n\x0estatementCount\x18\x01 \x01(\x04\x12\x36\n\x08\x61\x63\x63ounts\x18\x02 \x03(\x0b\x32$.rdbms.qle.FinalResult.AccountsEntry\x12\x10\n\x08warnings\x18\x03 \x03(\t\x1a/\n\rAccountsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x04:\x02\x38\x01\"\x85\x02\n\x0eQueryStatement\x12\x10\n\x08userName\x18\x01 \x01(\t\x12\x0c\n\x04text\x18\x02 \x01(\t\x12\x18\n\x10\x64\x65\x66\x61ultDatabases\x18\x03 \x01(\t\x12\x11\n\tsessionId\x18\x04 \x01(\t\x12\x34\n\x10sessionStartTime\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12-\n\tstartTime\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x11\n\tcancelled\x18\x07 \x01(\x08\x12\x14\n\x0csecondsTaken\x18\x08 \x01(\x02\x12\x18\n\x10\x64\x65stinationTable\x18\t \x01(\tB=\n\x1a\x61lation.sdk.rdbms.grpc.qleB\x12QueryLogExtractionP\x01Z\trdbms/qleb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'rdbms.qle_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\032alation.sdk.rdbms.grpc.qleB\022QueryLogExtractionP\001Z\trdbms/qle'
  _globals['_FINALRESULT_ACCOUNTSENTRY']._options = None
  _globals['_FINALRESULT_ACCOUNTSENTRY']._serialized_options = b'8\001'
  _globals['_REQUEST']._serialized_start=91
  _globals['_REQUEST']._serialized_end=209
  _globals['_RUNCONFIGURATION']._serialized_start=211
  _globals['_RUNCONFIGURATION']._serialized_end=336
  _globals['_RESPONSE']._serialized_start=339
  _globals['_RESPONSE']._serialized_end=469
  _globals['_FINALRESULT']._serialized_start=472
  _globals['_FINALRESULT']._serialized_end=632
  _globals['_FINALRESULT_ACCOUNTSENTRY']._serialized_start=585
  _globals['_FINALRESULT_ACCOUNTSENTRY']._serialized_end=632
  _globals['_QUERYSTATEMENT']._serialized_start=635
  _globals['_QUERYSTATEMENT']._serialized_end=896
# @@protoc_insertion_point(module_scope)
