# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fs/volume_check.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from queryservice_client.protobuf.common import configuration_pb2 as common_dot_configuration__pb2
from queryservice_client.protobuf.common import job_error_pb2 as common_dot_job__error__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15\x66s/volume_check.proto\x12\x0f\x66s.volume_check\x1a\x1a\x63ommon/configuration.proto\x1a\x16\x63ommon/job_error.proto\"\xf6\x01\n\x12VolumeCheckRequest\x12\x34\n\rconfiguration\x18\x01 \x01(\x0b\x32\x1d.common.ProtobufConfiguration\x12\x43\n\x08rootInfo\x18\x02 \x03(\x0b\x32\x31.fs.volume_check.VolumeCheckRequest.RootInfoEntry\x12\x19\n\x11is_include_filter\x18\x03 \x01(\x08\x1aJ\n\rRootInfoEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12(\n\x05value\x18\x02 \x01(\x0b\x32\x19.fs.volume_check.RootInfo:\x02\x38\x01\"5\n\x08RootInfo\x12\x12\n\ntsSnapshot\x18\x01 \x01(\x03\x12\x15\n\rcurrentVolume\x18\x02 \x01(\x03\"~\n\x13VolumeCheckResponse\x12-\n\x04item\x18\x01 \x01(\x0b\x32\x1d.fs.volume_check.ResponseItemH\x00\x12!\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x10.job_error.ErrorH\x00\x42\x15\n\x13VolumeCheckResponse\"]\n\x0cResponseItem\x12\x10\n\x08rootName\x18\x01 \x01(\t\x12\'\n\x06volume\x18\x02 \x01(\x0b\x32\x17.fs.volume_check.Volume\x12\x12\n\ntsSnapshot\x18\x03 \x01(\x03\"3\n\x06Volume\x12\x11\n\tfileCount\x18\x01 \x01(\x03\x12\x16\n\x0e\x64irectoryCount\x18\x02 \x01(\x03\x42\x42\n alation.sdk.fs.grpc.volume_checkB\x0bVolumeCheckP\x01Z\x0f\x66s/volume_checkb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'fs.volume_check_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n alation.sdk.fs.grpc.volume_checkB\013VolumeCheckP\001Z\017fs/volume_check'
  _globals['_VOLUMECHECKREQUEST_ROOTINFOENTRY']._options = None
  _globals['_VOLUMECHECKREQUEST_ROOTINFOENTRY']._serialized_options = b'8\001'
  _globals['_VOLUMECHECKREQUEST']._serialized_start=95
  _globals['_VOLUMECHECKREQUEST']._serialized_end=341
  _globals['_VOLUMECHECKREQUEST_ROOTINFOENTRY']._serialized_start=267
  _globals['_VOLUMECHECKREQUEST_ROOTINFOENTRY']._serialized_end=341
  _globals['_ROOTINFO']._serialized_start=343
  _globals['_ROOTINFO']._serialized_end=396
  _globals['_VOLUMECHECKRESPONSE']._serialized_start=398
  _globals['_VOLUMECHECKRESPONSE']._serialized_end=524
  _globals['_RESPONSEITEM']._serialized_start=526
  _globals['_RESPONSEITEM']._serialized_end=619
  _globals['_VOLUME']._serialized_start=621
  _globals['_VOLUME']._serialized_end=672
# @@protoc_insertion_point(module_scope)
