# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bi/bi.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from bi import mde_pb2 as bi_dot_mde__pb2
from bi import certify_pb2 as bi_dot_certify__pb2
from queryservice_client.protobuf.common import verify_pb2 as common_dot_verify__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0b\x62i/bi.proto\x12\x02\x62i\x1a\x1bgoogle/protobuf/empty.proto\x1a\x0c\x62i/mde.proto\x1a\x10\x62i/certify.proto\x1a\x13\x63ommon/verify.proto2\xd3\x02\n\x02\x42i\x12\x46\n\x19\x43onfigurationVerification\x12\x0f.verify.Request\x1a\x16.google.protobuf.Empty\"\x00\x12M\n\x0eListFileSystem\x12\x1d.bi.mde.ListFileSystemRequest\x1a\x18.bi.mde.BIObjectResponse\"\x00\x30\x01\x12S\n\x11RunFullExtraction\x12 .bi.mde.RunFullExtractionRequest\x1a\x18.bi.mde.BIObjectResponse\"\x00\x30\x01\x12\x61\n\x16propagateCertification\x12).bi.certify.PropagateCertificationRequest\x1a\x18.bi.mde.BIObjectResponse\"\x00\x30\x01\x42&\n\x13\x61lation.sdk.bi.grpcB\x07\x42iProtoP\x01\xa2\x02\x03GBMb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bi.bi_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\023alation.sdk.bi.grpcB\007BiProtoP\001\242\002\003GBM'
  _globals['_BI']._serialized_start=102
  _globals['_BI']._serialized_end=441
# @@protoc_insertion_point(module_scope)
