# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: common/cag.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10\x63ommon/cag.proto\x12\x03\x63\x61g\"\x1b\n\nCAGRequest\x12\r\n\x05token\x18\x01 \x01(\t\"b\n\x0b\x43\x41GResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12\x0f\n\x07message\x18\x03 \x01(\t\x12\x11\n\tprotoName\x18\x04 \x01(\t\x12\x10\n\x08protoObj\x18\x05 \x01(\x0c\x32;\n\x03\x43\x41G\x12\x34\n\rRemoteRequest\x12\x0f.cag.CAGRequest\x1a\x10.cag.CAGResponse\"\x00\x42H\n\x1b\x61lation.sdk.grpc.common.cagB\x1b\x43onnectorApplicationGatewayP\x01Z\ncommon/cagb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'common.cag_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033alation.sdk.grpc.common.cagB\033ConnectorApplicationGatewayP\001Z\ncommon/cag'
  _globals['_CAGREQUEST']._serialized_start=25
  _globals['_CAGREQUEST']._serialized_end=52
  _globals['_CAGRESPONSE']._serialized_start=54
  _globals['_CAGRESPONSE']._serialized_end=152
  _globals['_CAG']._serialized_start=154
  _globals['_CAG']._serialized_end=213
# @@protoc_insertion_point(module_scope)
