# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: asset/filter_extraction.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from queryservice_client.protobuf.common import configuration_pb2 as common_dot_configuration__pb2
from asset import filter_extraction_objects_pb2 as asset_dot_filter__extraction__objects__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x61sset/filter_extraction.proto\x12\x1bocf.asset.filter_extraction\x1a\x1a\x63ommon/configuration.proto\x1a%asset/filter_extraction_objects.proto\"O\n\x17\x46ilterExtractionRequest\x12\x34\n\rconfiguration\x18\x01 \x01(\x0b\x32\x1d.common.ProtobufConfiguration\"u\n\x18\x46ilterExtractionResponse\x12=\n\x06\x66ilter\x18\x01 \x01(\x0b\x32+.ocf.asset.filter_extraction_objects.FilterH\x00\x42\x1a\n\x18\x46ilterExtractionResponse2\x98\x01\n\x10\x46ilterExtraction\x12\x83\x01\n\x10\x46ilterExtraction\x12\x34.ocf.asset.filter_extraction.FilterExtractionRequest\x1a\x35.ocf.asset.filter_extraction.FilterExtractionResponse\"\x00\x30\x01\x42\x45\n(alation.sdk.asset.grpc.filter_extractionP\x01Z\x17\x61sset/filter_extractionb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'asset.filter_extraction_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n(alation.sdk.asset.grpc.filter_extractionP\001Z\027asset/filter_extraction'
  _globals['_FILTEREXTRACTIONREQUEST']._serialized_start=129
  _globals['_FILTEREXTRACTIONREQUEST']._serialized_end=208
  _globals['_FILTEREXTRACTIONRESPONSE']._serialized_start=210
  _globals['_FILTEREXTRACTIONRESPONSE']._serialized_end=327
  _globals['_FILTEREXTRACTION']._serialized_start=330
  _globals['_FILTEREXTRACTION']._serialized_end=482
# @@protoc_insertion_point(module_scope)
