# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rdbms/rdbms.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from queryservice_client.protobuf.common import verify_pb2 as common_dot_verify__pb2
from queryservice_client.protobuf.rdbms import mde_pb2 as rdbms_dot_mde__pb2
from queryservice_client.protobuf.rdbms import profiling_pb2 as rdbms_dot_profiling__pb2
from queryservice_client.protobuf.rdbms import qle_pb2 as rdbms_dot_qle__pb2
from queryservice_client.protobuf.rdbms import query_pb2 as rdbms_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11rdbms/rdbms.proto\x12\x05rdbms\x1a\x1bgoogle/protobuf/empty.proto\x1a\x13\x63ommon/verify.proto\x1a\x0frdbms/mde.proto\x1a\x15rdbms/profiling.proto\x1a\x0frdbms/qle.proto\x1a\x11rdbms/query.proto2\xa5\t\n\x05Rdbms\x12\x46\n\x19\x43onfigurationVerification\x12\x0f.verify.Request\x1a\x16.google.protobuf.Empty\"\x00\x12_\n\x10\x46ilterExtraction\x12\".rdbms.mde.FilterExtractionRequest\x1a#.rdbms.mde.FilterExtractionResponse\"\x00\x30\x01\x12\x65\n\x12MetadataExtraction\x12$.rdbms.mde.MetadataExtractionRequest\x1a%.rdbms.mde.MetadataExtractionResponse\"\x00\x30\x01\x12\\\n\x0fTableExtraction\x12!.rdbms.mde.TableExtractionRequest\x1a\".rdbms.mde.TableExtractionResponse\"\x00\x30\x01\x12?\n\x12QuerylogExtraction\x12\x12.rdbms.qle.Request\x1a\x13.rdbms.qle.Response0\x01\x12\x65\n\x0eTableProfiling\x12&.rdbms.profiling.TableProfilingRequest\x1a\'.rdbms.profiling.TableProfilingResponse\"\x00\x30\x01\x12h\n\x0f\x43olumnProfiling\x12\'.rdbms.profiling.ColumnProfilingRequest\x1a(.rdbms.profiling.ColumnProfilingResponse\"\x00\x30\x01\x12w\n\x14\x43ustomTableProfiling\x12,.rdbms.profiling.CustomTableProfilingRequest\x1a-.rdbms.profiling.CustomTableProfilingResponse\"\x00\x30\x01\x12t\n\x15\x43ustomColumnProfiling\x12-.rdbms.profiling.CustomColumnProfilingRequest\x1a(.rdbms.profiling.ColumnProfilingResponse\"\x00\x30\x01\x12S\n\x0cStartSession\x12 .rdbms.query.StartSessionRequest\x1a!.rdbms.query.StartSessionResponse\x12\x44\n\nEndSession\x12\x1e.rdbms.query.EndSessionRequest\x1a\x16.google.protobuf.Empty\x12@\n\x05Query\x12\x19.rdbms.query.QueryRequest\x1a\x1a.rdbms.query.QueryResponse0\x01\x12P\n\x0b\x43\x61ncelQuery\x12\x1f.rdbms.query.CancelQueryRequest\x1a .rdbms.query.CancelQueryResponseB.\n\x16\x61lation.sdk.rdbms.grpcB\nRdbmsProtoP\x01Z\x06rdbms/b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'rdbms.rdbms_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\026alation.sdk.rdbms.grpcB\nRdbmsProtoP\001Z\006rdbms/'
  _globals['_RDBMS']._serialized_start=155
  _globals['_RDBMS']._serialized_end=1344
# @@protoc_insertion_point(module_scope)
