# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rdbms/profiling.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from queryservice_client.protobuf.common import auth_pb2 as common_dot_auth__pb2
from queryservice_client.protobuf.common import configuration_pb2 as common_dot_configuration__pb2
from queryservice_client.protobuf.rdbms import mde_objects_pb2 as rdbms_dot_mde__objects__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15rdbms/profiling.proto\x12\x0frdbms.profiling\x1a\x11\x63ommon/auth.proto\x1a\x1a\x63ommon/configuration.proto\x1a\x17rdbms/mde_objects.proto\"\xae\x01\n\x15TableProfilingRequest\x12\x34\n\rconfiguration\x18\x01 \x01(\x0b\x32\x1d.common.ProtobufConfiguration\x12\x34\n\rtableRequests\x18\x02 \x03(\x0b\x32\x1d.rdbms.profiling.TableRequest\x12\x18\n\x04\x61uth\x18\x03 \x01(\x0b\x32\n.auth.Auth\x12\x0f\n\x07jdbcUri\x18\x04 \x01(\t\"\x81\x02\n\x0cTableRequest\x12\n\n\x02id\x18\x01 \x01(\x04\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x12\n\x06schema\x18\x03 \x01(\tB\x02\x18\x01\x12\x16\n\x0epopulationSize\x18\x04 \x01(\r\x12\x12\n\nsampleSize\x18\x05 \x01(\r\x12\x31\n\x10sensitiveColumns\x18\x07 \x03(\x0b\x32\x17.rdbms.profiling.Column\x12(\n\x07\x63olumns\x18\x08 \x03(\x0b\x32\x17.rdbms.profiling.Column\x12\x0f\n\x07timeout\x18\t \x01(\r\x12\x13\n\x0bschema_name\x18\n \x01(\t\x12\x14\n\x0c\x63\x61talog_name\x18\x0b \x01(\t\"U\n\x06\x43olumn\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\x04\x12\x31\n\ncolumnType\x18\x04 \x01(\x0b\x32\x1d.rdbms.mde_objects.ColumnType\"\xcb\x01\n\x16TableProfilingResponse\x12\n\n\x02id\x18\x01 \x01(\x04\x12(\n\nrowSamples\x18\x02 \x03(\x0b\x32\x14.rdbms.profiling.Row\x12\x1b\n\x13numberOfRowsSampled\x18\x03 \x01(\r\x12\x14\n\x0csecondsTaken\x18\x04 \x01(\r\x12\x0f\n\x07hasMore\x18\x05 \x01(\x08\x12\x37\n\x0f\x63olumnSummaries\x18\x06 \x03(\x0b\x32\x1e.rdbms.profiling.ColumnSummary\"\x15\n\x03Row\x12\x0e\n\x06values\x18\x01 \x03(\t\"\xc3\x01\n\rColumnSummary\x12\x39\n\x0c\x64istribution\x18\x01 \x03(\x0b\x32#.rdbms.profiling.ColumnDistribution\x12\x15\n\rnumberOfNulls\x18\x02 \x01(\r\x12\x1c\n\x14numberOfUniqueValues\x18\x03 \x01(\r\x12\x19\n\x11numberOfAllValues\x18\x04 \x01(\r\x12\'\n\x06\x63olumn\x18\x05 \x01(\x0b\x32\x17.rdbms.profiling.Column\"2\n\x12\x43olumnDistribution\x12\r\n\x05value\x18\x01 \x01(\t\x12\r\n\x05\x63ount\x18\x02 \x01(\r\"\xba\x01\n\x1b\x43ustomTableProfilingRequest\x12\x34\n\rconfiguration\x18\x01 \x01(\x0b\x32\x1d.common.ProtobufConfiguration\x12:\n\rtableRequests\x18\x02 \x03(\x0b\x32#.rdbms.profiling.CustomTableRequest\x12\x18\n\x04\x61uth\x18\x03 \x01(\x0b\x32\n.auth.Auth\x12\x0f\n\x07jdbcUri\x18\x04 \x01(\t\"V\n\x12\x43ustomTableRequest\x12.\n\x07request\x18\x01 \x01(\x0b\x32\x1d.rdbms.profiling.TableRequest\x12\x10\n\x08override\x18\x02 \x01(\t\"\x82\x01\n\x1c\x43ustomTableProfilingResponse\x12\x39\n\x08response\x18\x01 \x01(\x0b\x32\'.rdbms.profiling.TableProfilingResponse\x12\'\n\x06schema\x18\x02 \x03(\x0b\x32\x17.rdbms.profiling.Column\"\xaa\x01\n\x16\x43olumnProfilingRequest\x12\x34\n\rconfiguration\x18\x01 \x01(\x0b\x32\x1d.common.ProtobufConfiguration\x12/\n\x07request\x18\x02 \x01(\x0b\x32\x1e.rdbms.profiling.ColumnRequest\x12\x18\n\x04\x61uth\x18\x03 \x01(\x0b\x32\n.auth.Auth\x12\x0f\n\x07jdbcUri\x18\x04 \x01(\t\"\xce\x01\n\rColumnRequest\x12\x12\n\x06schema\x18\x01 \x01(\tB\x02\x18\x01\x12\r\n\x05table\x18\x02 \x01(\t\x12\x0e\n\x06\x63olumn\x18\x03 \x01(\t\x12\x12\n\nsampleSize\x18\x04 \x01(\r\x12\x0f\n\x07timeout\x18\x05 \x01(\r\x12:\n\x04type\x18\x06 \x01(\x0e\x32,.rdbms.mde_objects.ColumnType.NormalizedType\x12\x13\n\x0bschema_name\x18\x07 \x01(\t\x12\x14\n\x0c\x63\x61talog_name\x18\x08 \x01(\t\"\xa2\x01\n\x17\x43olumnProfilingResponse\x12;\n\x0c\x64istribution\x18\x01 \x01(\x0b\x32#.rdbms.profiling.ColumnDistributionH\x00\x12>\n\x05\x66inal\x18\x03 \x01(\x0b\x32-.rdbms.profiling.ColumnProfilingFinalResponseH\x00\x42\n\n\x08response\"u\n\x1c\x43olumnProfilingFinalResponse\x12.\n\nstatistics\x18\x02 \x03(\x0b\x32\x1a.rdbms.profiling.Statistic\x12\x0f\n\x07hasMore\x18\x03 \x01(\x08\x12\x14\n\x0csecondsTaken\x18\x05 \x01(\r\"(\n\tStatistic\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"\xed\x01\n\x1c\x43ustomColumnProfilingRequest\x12\x34\n\rconfiguration\x18\x01 \x01(\x0b\x32\x1d.common.ProtobufConfiguration\x12/\n\x07request\x18\x02 \x01(\x0b\x32\x1e.rdbms.profiling.ColumnRequest\x12;\n\x08override\x18\x03 \x01(\x0b\x32).rdbms.profiling.ColumnStatisticsOverride\x12\x18\n\x04\x61uth\x18\x04 \x01(\x0b\x32\n.auth.Auth\x12\x0f\n\x07jdbcUri\x18\x05 \x01(\t\"\x7f\n\x18\x43olumnStatisticsOverride\x12\x11\n\x07literal\x18\x01 \x01(\tH\x00\x12G\n\ttemplated\x18\x02 \x01(\x0b\x32\x32.rdbms.profiling.TemplatedColumnStatisticsOverrideH\x00\x42\x07\n\x05query\"\xa7\x01\n!TemplatedColumnStatisticsOverride\x12\x17\n\x0fnumericTemplate\x18\x01 \x01(\t\x12\x1a\n\x12nonNumericTemplate\x18\x02 \x01(\t\x12\x19\n\x11\x63olumnPlaceholder\x18\x03 \x01(\t\x12\x18\n\x10tablePlaceholder\x18\x04 \x01(\t\x12\x18\n\x10limitPlaceholder\x18\x05 \x01(\tB@\n alation.sdk.rdbms.grpc.profilingB\tProfilingP\x01Z\x0frdbms/profilingb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'rdbms.profiling_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n alation.sdk.rdbms.grpc.profilingB\tProfilingP\001Z\017rdbms/profiling'
  _globals['_TABLEREQUEST'].fields_by_name['schema']._options = None
  _globals['_TABLEREQUEST'].fields_by_name['schema']._serialized_options = b'\030\001'
  _globals['_COLUMNREQUEST'].fields_by_name['schema']._options = None
  _globals['_COLUMNREQUEST'].fields_by_name['schema']._serialized_options = b'\030\001'
  _globals['_TABLEPROFILINGREQUEST']._serialized_start=115
  _globals['_TABLEPROFILINGREQUEST']._serialized_end=289
  _globals['_TABLEREQUEST']._serialized_start=292
  _globals['_TABLEREQUEST']._serialized_end=549
  _globals['_COLUMN']._serialized_start=551
  _globals['_COLUMN']._serialized_end=636
  _globals['_TABLEPROFILINGRESPONSE']._serialized_start=639
  _globals['_TABLEPROFILINGRESPONSE']._serialized_end=842
  _globals['_ROW']._serialized_start=844
  _globals['_ROW']._serialized_end=865
  _globals['_COLUMNSUMMARY']._serialized_start=868
  _globals['_COLUMNSUMMARY']._serialized_end=1063
  _globals['_COLUMNDISTRIBUTION']._serialized_start=1065
  _globals['_COLUMNDISTRIBUTION']._serialized_end=1115
  _globals['_CUSTOMTABLEPROFILINGREQUEST']._serialized_start=1118
  _globals['_CUSTOMTABLEPROFILINGREQUEST']._serialized_end=1304
  _globals['_CUSTOMTABLEREQUEST']._serialized_start=1306
  _globals['_CUSTOMTABLEREQUEST']._serialized_end=1392
  _globals['_CUSTOMTABLEPROFILINGRESPONSE']._serialized_start=1395
  _globals['_CUSTOMTABLEPROFILINGRESPONSE']._serialized_end=1525
  _globals['_COLUMNPROFILINGREQUEST']._serialized_start=1528
  _globals['_COLUMNPROFILINGREQUEST']._serialized_end=1698
  _globals['_COLUMNREQUEST']._serialized_start=1701
  _globals['_COLUMNREQUEST']._serialized_end=1907
  _globals['_COLUMNPROFILINGRESPONSE']._serialized_start=1910
  _globals['_COLUMNPROFILINGRESPONSE']._serialized_end=2072
  _globals['_COLUMNPROFILINGFINALRESPONSE']._serialized_start=2074
  _globals['_COLUMNPROFILINGFINALRESPONSE']._serialized_end=2191
  _globals['_STATISTIC']._serialized_start=2193
  _globals['_STATISTIC']._serialized_end=2233
  _globals['_CUSTOMCOLUMNPROFILINGREQUEST']._serialized_start=2236
  _globals['_CUSTOMCOLUMNPROFILINGREQUEST']._serialized_end=2473
  _globals['_COLUMNSTATISTICSOVERRIDE']._serialized_start=2475
  _globals['_COLUMNSTATISTICSOVERRIDE']._serialized_end=2602
  _globals['_TEMPLATEDCOLUMNSTATISTICSOVERRIDE']._serialized_start=2605
  _globals['_TEMPLATEDCOLUMNSTATISTICSOVERRIDE']._serialized_end=2772
# @@protoc_insertion_point(module_scope)
