# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: common/error.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12\x63ommon/error.proto\x12\x05\x65rror\"\x18\n\x05\x45rror\x12\x0f\n\x07message\x18\x01 \x01(\tB?\n\x1d\x61lation.sdk.grpc.common.errorB\x0e\x43onnectorErrorP\x01Z\x0c\x63ommon/errorb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'common.error_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\035alation.sdk.grpc.common.errorB\016ConnectorErrorP\001Z\014common/error'
  _globals['_ERROR']._serialized_start=29
  _globals['_ERROR']._serialized_end=53
# @@protoc_insertion_point(module_scope)
