# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: policy/policy_sync.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from policy import policy_objects_pb2 as policy_dot_policy__objects__pb2
from queryservice_client.protobuf.common import auth_pb2 as common_dot_auth__pb2
from queryservice_client.protobuf.common import configuration_pb2 as common_dot_configuration__pb2
from queryservice_client.protobuf.common import error_pb2 as common_dot_error__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18policy/policy_sync.proto\x12\x10ocf.policy.rdbms\x1a\x1bpolicy/policy_objects.proto\x1a\x11\x63ommon/auth.proto\x1a\x1a\x63ommon/configuration.proto\x1a\x12\x63ommon/error.proto\"\xc1\x01\n\x12PolicySyncResponse\x12\x39\n\ttableLink\x18\x01 \x01(\x0b\x32$.ocf.policy.policy_objects.TableLinkH\x00\x12;\n\ncolumnLink\x18\x02 \x01(\x0b\x32%.ocf.policy.policy_objects.ColumnLinkH\x00\x12\x1d\n\x05\x65rror\x18\x03 \x01(\x0b\x32\x0c.error.ErrorH\x00\x42\x14\n\x12PolicySyncResponse\"\xf2\x01\n\x11PolicySyncRequest\x12\x34\n\rconfiguration\x18\x01 \x01(\x0b\x32\x1d.common.ProtobufConfiguration\x12\x18\n\x04\x61uth\x18\x02 \x01(\x0b\x32\n.auth.Auth\x12;\n\x0bpolicyApiId\x18\x03 \x01(\x0b\x32&.ocf.policy.policy_objects.PolicyApiId\x12P\n\x16policyObjectSyncValues\x18\x04 \x03(\x0b\x32\x30.ocf.policy.policy_objects.PolicyObjectSyncValue2\xd6\x01\n\x0fRdbmsPolicySync\x12`\n\x0fPolicySyncApply\x12#.ocf.policy.rdbms.PolicySyncRequest\x1a$.ocf.policy.rdbms.PolicySyncResponse\"\x00\x30\x01\x12\x61\n\x10PolicySyncRevoke\x12#.ocf.policy.rdbms.PolicySyncRequest\x1a$.ocf.policy.rdbms.PolicySyncResponse\"\x00\x30\x01\x42-\n\x1b\x61lation.sdk.ocf.policy.grpcB\x0cMetadataSyncP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'policy.policy_sync_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033alation.sdk.ocf.policy.grpcB\014MetadataSyncP\001'
  _globals['_POLICYSYNCRESPONSE']._serialized_start=143
  _globals['_POLICYSYNCRESPONSE']._serialized_end=336
  _globals['_POLICYSYNCREQUEST']._serialized_start=339
  _globals['_POLICYSYNCREQUEST']._serialized_end=581
  _globals['_RDBMSPOLICYSYNC']._serialized_start=584
  _globals['_RDBMSPOLICYSYNC']._serialized_end=798
# @@protoc_insertion_point(module_scope)
